/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: MoneyDOMPersistence.java,v 1.4 2002/01/17 18:37:09 max Exp $
 *
 */

package make.datamodel.composite;

import java.text.ParseException;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import make.xml.DOMUtil;

public abstract class MoneyDOMPersistence {
    public static Element toElement(Document doc, String tag, Currency c) {
        if (c==null)
            return null;
        return DOMUtil.createStringElement(doc, tag, c.getCode());
    }
    public static Element toElement(Document doc, String tag, Money m) {
        if (m==null)
            return null;
        Element el = doc.createElement(tag);
        el.appendChild(toElement(doc, "currency", m.getCurrency()));
        el.appendChild(DOMUtil.createStringElement(doc, "value", 
                                                   ""+m.getValue()));
        return el;
    }
    public static Currency toCurrency(Element el) 
        throws ParseException {
        String code = DOMUtil.getElementString(el);
        return code == null
            ?null
            :Currency.getByCode(code);
    }
    public static Money toMoney(Element el) 
        throws ParseException {
        if (el==null)
            return null;
        try {
            String valueString = DOMUtil.getElementString(el, "value");
            if (valueString==null)
                return null;
            long value = Long.parseLong(valueString);
            Element currencyEl = DOMUtil.getUniqueTag(el, "currency");
            Currency c = toCurrency(currencyEl);
            if (c==null)
                c = Currency.deutscheMark; //TODO: better default
            return new Money(value, c);
        } catch (NumberFormatException e) {
            throw new ParseException(e.toString(), 0);
        }
    }
}
