/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2002 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: MoneySQLPersistence.java,v 1.5 2002/01/14 17:25:45 max Exp $
 *
 */

package make.datamodel.composite;

import java.sql.PreparedStatement;
import java.sql.SQLException;
import java.sql.ResultSet;
import java.sql.Types;

public abstract class MoneySQLPersistence {
    public static void set(PreparedStatement ps, int[] idx, Currency c) 
        throws SQLException {
        if (c==null) {
            ps.setNull(idx[0]++, Types.VARCHAR);
        } else {
            ps.setString(idx[0]++, c.getCode());
        }
    }
    public static void set(PreparedStatement ps, int[] idx, Money m) 
        throws SQLException {
        if (m==null) {
            ps.setNull(idx[0]++, Types.INTEGER);
            set(ps, idx, (Currency)null);
        } else {
            ps.setLong(idx[0]++, m.getValue());
            set(ps, idx, m.getCurrency());
        }
    }
    public static Currency getCurrency(ResultSet rs, int[] idx) 
        throws SQLException {
        String code = rs.getString(idx[0]++);
        return code==null
            ?null
            :Currency.getByCode(code);
    }
    public static Money getMoney(ResultSet rs, int[] idx) 
        throws SQLException {
        long value = rs.getLong(idx[0]++);
        boolean wasNull = rs.wasNull();
        Currency currency = getCurrency(rs, idx);
        // TODO: better default value
        if (currency==null) 
            currency = Currency.euro;
        return wasNull
            ?null
            :new Money(value, currency);
    }
}
