/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: CachedEmbeddedManager.java,v 1.8 2001/10/11 21:31:10 max Exp $
 *
 */

package make.datamodel.embedded;

import java.io.IOException;
import java.io.InputStream;
import java.util.Hashtable;
import org.w3c.dom.Node;
import org.xml.sax.SAXException;

/**
 * EmbeddedManager implementation acts as proxy for another
 * EmbeddedManager instance. It caches all data once they
 * are retrieved. This may be used as wrapper for
 * EmbededManager instances which fetch their data
 * from a slow network connection.
 */
public class CachedEmbeddedManager extends MemoryEmbeddedManager 
    implements ProxyEmbeddedManager {
    /*properties*******************************/
    protected EmbeddedManager original;
    protected String[] names;
    /*Constructor*****************************/
    /**
     * Creates a new cache instance.
     * @param _em the EmbeddedManager instance that is to be cached
     */
    public CachedEmbeddedManager(EmbeddedManager _em) { 
	original = _em;
    }
    public String toString() { return original.toString(); }
    /*ProxyEmbeddedManager*************************/
    public EmbeddedManager getOriginal() {
	return original;
    }
    /*EmbeddedManager***************************/
    public String[] getNames() throws IOException {
	if (names==null)
	    names = original.getNames();
	return names;
    }
    public Hashtable getSizes() throws IOException {
	return original.getSizes();
    }
    public boolean contains(String name) { 
	if (names==null)
	    try {
		names = original.getNames();
	    } catch (IOException e) {
		return false;
	    }
	for (int z=0; z<names.length; z++)
	    if (names[z].equals(name))
		return true;
	return false;
    }
    public void replaceEntry(String name, InputStream data)
	throws IOException {
	names = null;
	super.replaceEntry(name, data);
	original.replaceEntry(name, super.getEntry(name));
    }
    public InputStream getEntry(String name) throws IOException {
	InputStream is = super.getEntry(name);
	if (is==null) {
	    is = original.getEntry(name);
	    if (is==null) return null;
	    super.replaceEntry(name, is);
	    return super.getEntry(name);
	} else
	    return is;
    }
    public void replaceDocument(Node n) throws IOException {
	original.replaceDocument(n);
	super.replaceDocument(n);
    }
    public Node getDocument() throws IOException, SAXException {
	Node n = super.getDocument();
	if (n==null) {
	    n = original.getDocument();
	    if (n!=null)
		super.replaceDocument(n);
	}
	return n;
    }
}
