/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: DocumentReplaceEmbeddedManager.java,v 1.2 2001/10/11 21:31:46 max Exp $
 *
 */

package make.datamodel.embedded;

import java.io.IOException;
import java.io.InputStream;
import java.util.Hashtable;
import org.w3c.dom.Node;
import org.xml.sax.SAXException;

/**
 * EmbeddedManager implementation acts as a proxy for another
 * EmbeddedManager instance. It just keeps track of its own
 * document property.
 */
public class DocumentReplaceEmbeddedManager extends MemoryEmbeddedManager 
    implements ProxyEmbeddedManager {
    /*properties*******************************/
    protected EmbeddedManager original;
    protected Node document;
    /*Constructor*****************************/
    public DocumentReplaceEmbeddedManager(EmbeddedManager _em,
					  Node _doc) {
	original = _em;
	document = _doc;
    }
    public String toString() { 
	return "[DocumentReplace: original="+original.toString()+"]";
    }
    /*ProxyEmbeddedManager*************************/
    public EmbeddedManager getOriginal() {
	return original;
    }
    /*EmbeddedManager***************************/
    public String[] getNames() throws IOException {
	return original.getNames();
    }
    public Hashtable getSizes() throws IOException {
	return original.getSizes();
    }
    public boolean contains(String name) { 
	return original.contains(name);
    }
    public void replaceEntry(String name, InputStream data)
	throws IOException {
	super.replaceEntry(name, data);
    }
    public InputStream getEntry(String name) throws IOException {
	return super.getEntry(name);
    }
    public void replaceDocument(Node n) throws IOException {
	document = n;
    }
    public Node getDocument() throws IOException, SAXException {
	return document;
    }
}
