/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: EmbeddedManager.java,v 1.7 2001/10/11 21:30:45 max Exp $
 *
 */

package make.datamodel.embedded;

import java.io.IOException;
import java.io.InputStream;
import java.util.Hashtable;
import org.w3c.dom.Node;
import org.xml.sax.SAXException;

/**
 * EmbeddedManager is an object that manages an XML file
 * plus all its linked files, e.g. Images or other embedded objects.
 */
public interface EmbeddedManager {
    /**
     * Returns the names of all linked objects
     */
    String[] getNames() throws IOException;
    /**
     * Returns the sizes of all linked objects, if known.
     * The return value may also be null of no size is available.
     */
    Hashtable getSizes() throws IOException;
    /**
     * Returns true if a linked object with the specified name exists.
     */
    boolean contains(String name);
    /**
     * Replaces an object with the specified data.
     * @param name the object's name
     * @param data the stream where the data can be loaded, or
     *             null if the object is to be deleted
     */
    void replaceEntry(String name, InputStream data)
	throws IOException;
    /**
     * Returns an object
     * @param name the name of the requested object
     */
    InputStream getEntry(String name) throws IOException;
    /**
     * Writes a new version of the main document
     * @param n the root element
     */
    void replaceDocument(Node n) throws IOException;
    /**
     * Gets the current main document
     */
    Node getDocument() throws IOException, SAXException;
}
