/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: URLEmbeddedManager.java,v 1.1 2001/10/11 21:44:21 max Exp $
 *
 */

package make.datamodel.embedded;

import java.io.IOException;
import java.io.InputStream;
import java.util.Hashtable;
import java.net.URL;
import org.w3c.dom.Node;
import org.w3c.dom.Document;
import org.xml.sax.SAXException;
import make.xml.DOMUtil;
import make.xml.SchemaManager;

/**
 * EmbeddedManager implementation that can read documents from
 * an URL. It is read-only.
 */
public class URLEmbeddedManager implements EmbeddedManager {
    /*properties*****************************/
    protected SchemaManager schemaManager;
    protected URL url;
    /*Constructor*****************************/
    /**
     * Creates a new instance.
     * @param _url the source URL
     * @param _fm the SchemaManager which is used to lookup
     *            tips to write the XML file.
     */
    public URLEmbeddedManager(URL _url, SchemaManager _fm) 
	throws IOException {
	url = _url;
	schemaManager = _fm;
    }
    public String toString() { return url.toString(); }
    /*EmbeddedManager******************************************/
    public String[] getNames() {
	// no image names available
	return new String[]{};
    }
    public Hashtable getSizes() {
	// no image sizes available
	return new Hashtable();
    }
    public boolean contains(String name) {
	return false;
    }
    public void replaceEntry(String name, InputStream data)
	throws IOException {
	throw new IOException("URLEmbeddedManager is read-only");
    }
    public InputStream getEntry(String name)
	throws IOException {
	return null;
    }
    public void replaceDocument(Node n)
	throws IOException {
	throw new IOException("URLEmbeddedManager is read-only");
    }
    public Node getDocument()
	throws IOException, SAXException {
	return DOMUtil.parse(url.openStream()).getDocumentElement();
    }
}
