/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: ParseSlot.java,v 1.4 2001/08/20 09:23:38 max Exp $
 *
 */

package make.datamodel.slot;

import java.text.ParseException;
import java.text.Format;

/**
 * This experimental Slot implementation acts as an adapter
 * for an existing Slot object. It filters all values read and
 * written through a java.text.Format object.
 * When calling getValue, it calls the parseObject method, and
 * when calling setValue, it calls the format method of Format.
 * This is the direct opposite of FormatSlot.
 */
public class ParseSlot implements Slot {
    /*properties********************/
    private Slot original;
    private Format format;
    /*Constructor********************/
    /**
     * Creates a new ParseSlot object.
     * @param _org the original slot
     * @param _fmt the Format object that is used as filter
     */
    public ParseSlot(Slot _org, Format _fmt) {
	original = _org; format = _fmt;
    }
    /*Slot***************************/
    public void setValue(Object v) throws ParseException {
	original.setValue(format.format(v));
    }
    public Object getValue() throws ParseException {
	return format.parseObject((String)original.getValue());
    }
}
