/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2002 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: ReflectionSlot.java,v 1.1 2002/01/03 12:22:10 max Exp $
 *
 */

package make.datamodel.slot;

import java.lang.reflect.Method;
import java.text.ParseException;
import make.util.Debug;

public class ReflectionSlot implements Slot {
    /*properties******************/
    protected Object object;
    protected Method getMethod, setMethod;

    /*Constructor***************/
    public ReflectionSlot(Object _obj, Method _get, Method _set) {
        object = _obj;
        getMethod = _get; setMethod = _set;
    }

    /*Slot************************/
    public void setValue(Object v) throws ParseException {
        if (setMethod==null)
            return;
        try {
            setMethod.invoke(object, new Object[]{v});
        } catch (Exception e) {
            Debug.report(e);
            throw new ParseException(e.toString(), 0);
        }
    }
    public Object getValue() throws ParseException {
        if (getMethod==null)
            return null;
        try {
            return getMethod.invoke(object, new Object[]{});
        } catch (Exception e) {
            Debug.report(e);
            throw new ParseException(e.toString(), 0);
        }
    }
}
