/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: DualOutputStream.java,v 1.3 2001/08/20 09:23:38 max Exp $
 *
 */

package make.io;

import java.io.OutputStream;
import java.io.IOException;

/**
 * DualOutputStream is a OutputStream extension that duplicates
 * everything that is written to it into two other OutputStream
 * objects that were specified in the constructor.
 */
public class DualOutputStream extends OutputStream {
    /*properties***************************/
    protected OutputStream os1, os2;
    /*Constructor***************************/
    public DualOutputStream(OutputStream _os1, OutputStream _os2) {
	os1 = _os1; os2 = _os2;
    }
    /*OutputStream**************************/
    public void write(int b) throws IOException {
	os1.write(b); os2.write(b);
    }
    public void write(byte b[], int off, int len) throws IOException {
	os1.write(b, off, len);
	os2.write(b, off, len);
    }
    public void flush() throws IOException {
	os1.flush(); os2.flush();
    }
    public void close() throws IOException {
	os1.close(); os2.close();
    }
}
