/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: DualWriter.java,v 1.3 2001/08/20 09:23:38 max Exp $
 *
 */

package make.io;

import java.io.Writer;
import java.io.IOException;

/**
 * DualWriter is a Writer extension that duplicates
 * everything that is written to it into two other Writer
 * objects that were specified in the constructor.
 */
public class DualWriter extends Writer {
    /*properties***************************/
    protected Writer w1, w2;
    /*Constructor***************************/
    public DualWriter(Writer _w1, Writer _w2) {
	w1 = _w1; w2 = _w2;
    }
    /*Writer**************************/
    public void write(int b) throws IOException {
	w1.write(b); w2.write(b);
    }
    public void write(char b[], int off, int len) throws IOException {
	w1.write(b, off, len);
	w2.write(b, off, len);
    }
    public void flush() throws IOException {
	w1.flush(); w2.flush();
    }
    public void close() throws IOException {
	w1.close(); w2.close();
    }
}
