/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: InputStreamDumper.java,v 1.3 2001/08/20 09:23:38 max Exp $
 *
 */

package make.io;

import java.io.OutputStream;
import java.io.InputStream;
import java.io.IOException;

/**
 * This class copies acts as a proxy for
 * an InputStream object and dumps everything that was read
 * to an OutputStream object as a copy.
 *
 * This may be used for debugging purposes.
 */
public class InputStreamDumper extends InputStream {
    /*properties***************************/
    protected InputStream in;
    protected OutputStream out;
    /*Constructor***************************/
    /**
     * Creates a new instance.
     * @param _in the InputStream object to be wrapped
     * @param _out the OutputStream object where we will write a copy
     */
    public InputStreamDumper(InputStream _in, OutputStream _out) {
	in = _in; out = _out;
    }
    /*InputStream**************************/
    public int read() throws IOException {
	int i = in.read();
	out.write(i);
	return i;
    }
    public int read(byte b[], int off, int len) throws IOException {
	int len2 = in.read(b, off, len);
	out.write(b, off, len2);
	return len2;
    }
    public long skip(long n) throws IOException {
	return in.skip(n);
    }
    public int available() throws IOException {
	return in.available();
    }
    public void close() throws IOException {
	in.close();
    }
    public void mark(int readLimit) {
	in.mark(readLimit);
    }
    public void reset() throws IOException {
	in.reset();
    }
    public boolean markSupported() {
	return in.markSupported();
    }
}
