/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: AbstractMessage.java,v 1.4 2001/08/20 09:23:38 max Exp $
 *
 */

package make.mime;

import java.util.Enumeration;
import java.util.Hashtable;
import java.io.IOException;
import java.io.InputStream;
import make.util.EmptyEnumeration;

/**
 * Default implementation of Message.
 * It implements basic methods like header handling.
 */
public abstract class AbstractMessage implements Message {
    /*properties************************/
    protected Hashtable header;
    /*Constructor***********************/
    /**
     * Creates an instance with an empty header.
     */
    protected AbstractMessage() {
    }
    /**
     * Creates an instance with the specified header.
     * @param _h the header
     *           Do not re-use this hashtable in your code
     */
    protected AbstractMessage(Hashtable _h) {
	header = _h;
    }
    /*AbstractMessage*********************/
    /**
     * Sets a header value.
     * @param name the name of the header
     * @param value the value of the header
     */
    public String setHeader(String name, String value) {
	if (header==null)
	    header = new Hashtable();
	return value==null
	    ?(String)header.remove(name)
	    :(String)header.put(name, value);
    }
    /*Message******************************/
    public String getHeader(String name) {
	return header==null ? null : (String)header.get(name);
    }
    public Enumeration getHeaderNames() {
	return header==null
	    ? new EmptyEnumeration()
		: header.keys();
    }
    public abstract InputStream getInputStream() 
	throws IOException;
}
