/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: FormDataUtil.java,v 1.3 2001/08/20 09:23:38 max Exp $
 *
 */

package make.mime;

import java.util.Hashtable;
import java.util.Enumeration;
import java.io.IOException;
import java.io.ByteArrayOutputStream;
import make.io.Streams;

public abstract class FormDataUtil {
    public static final String VALUE_ENCODING = "utf-8";
    public static Hashtable decodeMultiPartFormData(Message msg) 
	throws IOException {
	MultiPartDecoder dec = new MultiPartDecoder(msg);
	Hashtable ht = new Hashtable();
	while (dec.hasMoreParts()) {
	    Message part = dec.nextPart();
	    String name = MIMEUtil.getParameter(part.getHeader("Content-Disposition"), "name");
	    if (name==null) {
		name = part.getHeader("Content-Id");
		if (name==null)
		    continue;
	    }
	    String value = MIMEUtil.readString(part);
	    ht.put(name, value);
	}
	return ht;
    }
    public static Hashtable decodeFormData(Message msg) 
	throws IOException {
	if (MIMEUtil.isContentType(msg, "multipart/form-data"))
	    return decodeMultiPartFormData(msg);
	throw new IllegalArgumentException("unknown content type");
    }
    public static Message encodeMultiPartFormData(Hashtable ht)
	throws IOException {
	ByteArrayOutputStream baos = new ByteArrayOutputStream();
	MultiPartEncoder enc = new MultiPartEncoder(baos);
	for (Enumeration enum=ht.keys(); enum.hasMoreElements();) {
	    String name = (String)enum.nextElement();
	    String value = (String)ht.get(name);
	    byte[] data = Streams.toByteArray(value, VALUE_ENCODING);
	    Hashtable header = new Hashtable();
	    header.put("Content-Disposition", "form-data; name="+name);
	    header.put("Content-Type", "text/plain; charset="+VALUE_ENCODING);
	    header.put("Content-Transfer-Encoding", "quoted-printable");
	    enc.writeMessage(new ArrayMessage(data, header));
	}
	enc.close();
	Hashtable header = new Hashtable();
	header.put("Content-Type", "multipart/form-data");
	return new ArrayMessage(baos.toByteArray(), header);
    }
    public static Message encodeFormData(Hashtable ht, String type) 
	throws IOException {
	if (type.equals("multipart/form-data"))
	    return encodeMultiPartFormData(ht);
	throw new IllegalArgumentException("unknown content type");
    }
}
