/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: JarResourceLoader.java,v 1.1 2001/10/11 22:30:16 max Exp $
 *
 */

package make.module;

import java.io.IOException;
import java.io.FileNotFoundException;
import java.io.InputStream;
import java.net.URL;
import java.net.MalformedURLException;
import make.util.Debug;
import make.io.Streams;

/**
 * JarResourceLoader loads resources from a JAR file using the Java
 * URL syntax.
 */
public class JarResourceLoader 
    implements ResourceLoader {
    /*properties*******************************/
    protected String urlPrefix;
    /*Constructor******************************/
    /**
     * Creates a new ResourceLoader instance
     * @param _url the URL object pointing to the JAR file
     */
    public JarResourceLoader(URL _url) {
	urlPrefix = "jar:"+_url+"!";
    }
    public String toString() {
	return "[JarResourceLoader urlPrefix="+urlPrefix+"]";
    }
    protected String normalizeName(String name) {
	while (name.startsWith(".") || name.startsWith("//"))
	    name = name.substring(1);
	if (!name.startsWith("/"))
	    name = '/'+name;
	return name;
    }
    /*ResourceLoader***************************/
    public URL getResource(String name) {
	try {
	    return new URL(urlPrefix+normalizeName(name));
	} catch(MalformedURLException e) {
	    Debug.report(e);
	    return null;
	}
    }
    public InputStream getResourceAsStream(String name) {
	URL url = getResource(name);
	if (url==null)
	    return null;
	try {
	    return url.openStream();
	} catch (FileNotFoundException e) {
	    return null;
	} catch (IOException e) {
	    Debug.report(e);
	    return null;
	}
    }
    public byte[] loadResource(String name) {
	InputStream is = getResourceAsStream(name);
	if (is==null)
	    return null;
	try {
	    return Streams.streamToByteArray(is);
	} catch (IOException e) {
	    Debug.report(e);
	    return null;
	}
    }
}
