/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: PathResourceLoader.java,v 1.4 2001/08/20 09:23:39 max Exp $
 *
 */

package make.module;

import java.io.File;
import java.io.InputStream;
import java.io.FileInputStream;
import java.io.IOException;
import java.net.URL;
import java.net.MalformedURLException;
import make.util.Debug;

/**
 * PathResourceLoader loads resources as files from a specified
 * directory and its sub-directories.
 */
public class PathResourceLoader 
    implements ResourceLoader {
    /*properties*******************************/
    protected File path;
    /*Constructor******************************/
    /**
     * Creates a new ResourceLoader instance
     * @param _p the path where this object will look for resources
     */
    public PathResourceLoader(File _p) {
	path = _p;
    }
    public String toString() {
	return "[PathResourceLoader path="+path+"]";
    }
    /**
     * Creates a file object
     * @param name the filename
     */
    public File getFile(String name) {
	name = name.replace('/', File.separatorChar);
	File f = new File(path, name);
	if (f.exists() && f.canRead())
	    return f;
	return null;
    }
    /*ResourceLoader***************************/
    public URL getResource(String name) {
	File f = getFile(name);
	if (f!=null)
	    try {
		return new URL("file", null, f.getAbsolutePath());
	    } catch(MalformedURLException e) {
		Debug.report(e);
	    }
	return null;
    }
    public InputStream getResourceAsStream(String name) {
	File f = new File(path, name);
	if (f!=null)
	    try {
		return new FileInputStream(f);
	    } catch(IOException e) {
		Debug.report(e);
	    }
	return null;
    }
    public byte[] loadResource(String name) {
	File f = new File(path, name);
	if (f!=null)
	    try {
		if (f.length()>(64*1024*1024))
		    return null;
		InputStream is = new FileInputStream(f);
		byte[] data = new byte[(int)f.length()];
		is.read(data);
		is.close();
		return data;
	    } catch(IOException e) {
		Debug.report(e);
	    }
	return null;
    }
}
