/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: AsyncRunnableTask.java,v 1.3 2001/08/20 09:23:39 max Exp $
 *
 */

package make.scheduler;

import java.util.Date;
import make.util.Debug;

public class AsyncRunnableTask implements Task {
    /***properties*************************/
    protected Term term;
    protected Runnable runnable;
    protected Date next;
    protected Thread thread;
    /***Constructor**********/
    public AsyncRunnableTask(Term _term, Runnable _run) {
	term = _term; runnable = _run; 
	next = term.getNextTerm(null);
    }
    public String toString() {
	return "[AsyncRunnableTask term="+term+" runnable="+runnable+"]";
    }
    /***Task*************/
    public Date getNextTime() {
	return next;
    }
    public synchronized void run() {
	if (Debug.DEBUG && next==null)
	    throw new InternalError("next==null in Task::run");
	if (thread!=null) {
	    if (thread.isAlive())
		return;
	    else
		thread = null;
	}
	thread = new Thread(runnable);
	thread.start();
	next = term.getNextTerm(next);
    }
}
