/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: DefaultConnectionFactory.java,v 1.1 2001/11/08 22:29:40 max Exp $
 *
 */

package make.sql;

import java.sql.Connection;
import java.sql.SQLException;
import java.sql.DriverManager;
import make.util.Debug;

/**
 * The default ConnectionFactory implementation.
 * All information is passed to the constructor.
 */
public class DefaultConnectionFactory implements ConnectionFactory {
    /*properties********************************/
    protected String url, user, password;
    /*Constructor************************************/
    /**
     * Creates a new instance.
     * @param _driver the Java class that is loaded to initialize the JDBC driver.
     *                May be null if the driver is already initialized.
     * @param _url the URL used to connect to the database
     * @param _user the username passed to the database driver
     * @param _pw the clear-text password passed to the database driver
     */
    public DefaultConnectionFactory(String _driver, String _url,
                                    String _user, String _pw) {
        url = _url; user = _user; password = _pw;
        if (_driver!=null)
            try {
                Class.forName(_driver);
            } catch (Exception e) {
                Debug.report(e, "trying to register JDBC driver "+_driver);
            }
    }
    /**
     * Creates a new instance without authentification.
     * @param _driver the Java class that is loaded to initialize the JDBC driver.
     *                May be null if the driver is already initialized.
     * @param _url the URL used to connect to the database
     */
    public DefaultConnectionFactory(String _driver, String _url) {
        this(_driver, _url, null, null);
    }
    /*ConnectionFactory***************************/
    public Connection createConnection() throws SQLException {
        return DriverManager.getConnection(url, user, password);
    }
    public String toString() {
        return "DefaultConnectionFactory[url="+url+"]";
    }
}
