/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: PooledConnection.java,v 1.2 2001/12/18 19:36:13 max Exp $
 *
 */

package make.sql;

import java.sql.Connection;
import java.sql.SQLException;
import java.util.Hashtable;
import java.util.Enumeration;
import make.util.Debug;

public class PooledConnection {

    /*properties*********************************/
    private ConnectionFactory connectionFactory;
    private Connection[] connections;
    private Hashtable threads = new Hashtable();
    private int nextConnection = 0;

    /*Constructor*************************************/
    public PooledConnection(ConnectionFactory _cf, int poolSize)
        throws SQLException {
        connectionFactory = _cf;
        connections = new Connection[poolSize];
        // initialize first connection
        connections[nextConnection] = connectionFactory.createConnection();
    }

    /*Internal**********************************/
    private int nextIndex() {
        final int idx = nextConnection;
        nextConnection++;
        if (nextConnection>=connections.length)
            nextConnection = 0;
        return idx;
    }
    private Connection getConnection2() throws SQLException {
        return getConnection(nextIndex());
    }
    private Connection getConnection(int idx) throws SQLException {
        if (connections[idx]==null)
            reconnect(idx);
        return connections[idx];
    }
    private int getNumber(Thread thread) {
        Integer idx = (Integer)threads.get(thread);
        return idx==null ? -1 : idx.intValue();
    }
    protected void garbageCollection() {
        for (Enumeration enum=threads.keys();
             enum.hasMoreElements();) {
            Thread t = (Thread)enum.nextElement();
            if (!t.isAlive())
                threads.remove(t);
        }
    }
    protected synchronized void reconnect(int z) throws SQLException {
        synchronized(this) {
            if (connections[z]!=null) {
                try {
                    connections[z].close();
                } catch (SQLException e) {
                }
                connections[z] = null;
                System.gc();
            }
            connections[z] = connectionFactory.createConnection();
        }
    }
    protected synchronized void reconnect(Thread t) throws SQLException {
        reconnect(getNumber(t));
    }

    /*Connection**************************/
    public Connection getConnection() throws SQLException {
        garbageCollection();
        Thread t = Thread.currentThread();
        int idx = getNumber(t);
        if (idx==-1) {
            idx = nextIndex();
            threads.put(t, new Integer(idx));
        }
        return getConnection(idx);
    }
    public synchronized void reconnect() throws SQLException {
        reconnect(Thread.currentThread());
    }
    public void close() {
        for (int z=0; z<connections.length; z++) {
            if (connections[z]!=null) {
                try {
                    connections[z].close();
                } catch (SQLException e) {
                    Debug.report(e);
                }
            }
        }
        connectionFactory = null;
        connections = null;
        threads = null;
    }
}
