/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: KeyStrokeButton.java,v 1.4 2001/08/20 09:23:39 max Exp $
 *
 */

package make.swing;

import java.awt.event.ActionListener;
import javax.swing.KeyStroke;
import javax.swing.JComponent;
import make.util.Debug;

/**
 * GenericButton implementation that is a hotkey.
 * When the user presses the specified hotkey,
 * an ActionEvent is fired.
 */
public class KeyStrokeButton implements GenericButton {
    /*properties****************************/
    protected JComponent component;
    protected KeyStroke keyStroke;
    protected String command;
    protected int condition;
    protected ActionListener listener;
    /*Constructor**************************/
    /**
     * Creates a new KeyStrokeButton
     * @param _c the component where the hotkey is installed
     * @param _cmd the action command
     * @param _ks the hotkey
     * @param _cond the condition;
     *              see JComponent.registerKeyboardAction for details
     */
    public KeyStrokeButton(JComponent _c, String _cmd, 
			   KeyStroke _ks, int _cond) { 
	component = _c; command = _cmd;
	keyStroke = _ks; condition = _cond;
    }
    /*GenericButton*************************/
    public Object getActionSource() { return component; }
    public String getActionCommand() { return command; }
    public void addActionListener(ActionListener al) {
	if (listener==null) {
	    component.registerKeyboardAction(al, command, keyStroke, condition);
	    listener = al;
	} else if (Debug.DEBUG)
	    System.err.println("WARNING: duplicate register of keystroke "+keyStroke);
    }
    public void removeActionListener(ActionListener al) {
	if (listener==al) {
	    component.unregisterKeyboardAction(keyStroke);
	    listener = null;
	} else if (Debug.DEBUG)
	    System.err.println("WARNING: invalid unregister of keystroke "+keyStroke);
    }
    public void setEnabled(boolean _e) {}
    public void setSelected(boolean _p) {}
}
