/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: ProxyClipboard.java,v 1.5 2001/08/20 09:23:39 max Exp $
 *
 */

package make.swing;

import java.io.IOException;
import java.awt.datatransfer.DataFlavor;
import java.awt.datatransfer.Transferable;
import java.awt.datatransfer.Clipboard;
import java.awt.datatransfer.ClipboardOwner;
import java.awt.datatransfer.UnsupportedFlavorException;
import java.awt.datatransfer.StringSelection;
import make.util.Debug;

/**
 * This is a hack to enable old JDK 1.1 applications
 * to use the full clipboard functionality.
 * It acts as a proxy for the original clipboard
 * provided by AWT.
 * Whenever the user copies something to the clipboard,
 * the original data is cached here and retrieved when
 * pasting. That prevents the operating system and the
 * Java Virtual Machine to destroy or modify data.
 */
public class ProxyClipboard extends Clipboard 
    implements ClipboardOwner {
    /*properties***********************/
    protected Clipboard original;
    protected boolean lostLock = false;
    /*Constructor**********************/
    /**
     * Creates a new instance.
     * @param _original the clipboard provided by AWT.
     */
    public ProxyClipboard(Clipboard _original) {
	super(_original.getName());
	original = _original;
    }
    /*Clipboard*************************/
    public synchronized void setContents(Transferable _contents,
					 ClipboardOwner _owner) {
	super.setContents(_contents, _owner);
	try {
	    lostLock = true;
	    original.setContents(_contents, this);
	    if (original.getContents(this) instanceof StringSelection) {
		try {
		    String data = (String)_contents.getTransferData(DataFlavor.stringFlavor);
		    StringSelection ss = new StringSelection(data);
		    original.setContents(ss, this);
		} catch (UnsupportedFlavorException e) {
		} catch (IOException e) {
		    if (Debug.DEBUG)
			Debug.report(e);
		}
	    }
	} finally {
	    lostLock = false;
	}
    }
    public synchronized Transferable getContents(Object requestor) {
	Transferable ct = super.getContents(requestor);
	return ct==null
	    ?original.getContents(requestor)
	    :ct;
    }
    /*ClipboardOwner*************************/
    public void lostOwnership(Clipboard _clipboard,
			      Transferable _contents) {
	if (!lostLock) {
	    if (owner!=null) {
		owner.lostOwnership(this, contents);
		owner = null;
	    }
	    contents = null;
	}
    }
}
