/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: ThreadActionListener.java,v 1.4 2001/08/20 09:23:39 max Exp $
 *
 */

package make.swing;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

/**
 * This ActionListener wrapper creates a new thread for
 * every action caught and runs the original ActionListener
 * in the new thread.
 * Use it to listen to actions asynchonously.
 */
public class ThreadActionListener implements ActionListener {
    /*properties*****************************/
    protected ActionListener actionListener;
    /*Constructor***************************/
    /**
     * Creates a new instance.
     * @param _al the original ActionListener
     */
    public ThreadActionListener(ActionListener _al) {
	actionListener = _al;
    }
    /*ActionListener******************************/
    public synchronized void actionPerformed(final ActionEvent evt) {
	Thread thread = new Thread("threadAction for "+actionListener) {
		public void run() {
		    actionListener.actionPerformed(evt);
		}
	    };
	thread.setDaemon(true);
	thread.start();
    }
}
