/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: FrameDescriptionCache.java,v 1.1 2001/12/22 12:12:23 max Exp $
 *
 */

package make.swing.bt;

import java.util.Map;
import java.util.HashMap;
import java.util.Locale;
import java.io.InputStream;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import make.util.Debug;
import make.xml.DOMUtil;

public final class FrameDescriptionCache {
    /*properties***************************/
    protected static Map cache = new HashMap();

    /*Methods*********************************/
    public static FrameDescription loadFrameDescription(Class cls, String path,
                                                        Locale locale) {
        try {
            InputStream is = cls.getResourceAsStream(path);
            if (is==null)
                throw new NullPointerException("resource "+path+" not found");
            Document doc = DOMUtil.parse(is);
            if (doc==null)
                throw new NullPointerException("resource "+path+" is empty");
            Element root = doc.getDocumentElement();
            if (root==null)
                throw new NullPointerException("resource "+path+" contains no root element");
            return new FrameDescription(root, cls, locale);
        } catch (Exception e) {
            System.err.println("ERROR: exception while trying to load FD "+path);
            Debug.report(e);
            return new FrameDescription("ERROR");
        }
    }
    public static FrameDescription getFrameDescription(Class cls, String path,
                                                       Locale locale) {
        String key = path+"_"+locale;
        FrameDescription fd = (FrameDescription)cache.get(key);
        if (fd!=null)
            return fd;
        fd = loadFrameDescription(cls, path, locale);
        cache.put(key, fd);
        return fd;
    }
}
