/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: MenuDescription.java,v 1.7 2001/12/20 16:49:08 max Exp $
 *
 */

package make.swing.bt;

import java.util.Locale;
import java.awt.Container;
import javax.swing.JMenu;
import org.w3c.dom.Element;
import make.xml.DOMUtil;
import make.util.Strings;

public class MenuDescription extends PopupMenuDescription {
    /***properties**************************/
    protected String name, label, before;
    protected char mnemonic = 0;
    /***Constructor****************************/
    public MenuDescription(ButtonContainer _bc, Element d, Class cls, Locale locale) {
        super(_bc, DOMUtil.getUniqueTag(d, "items"), cls, locale);
        name = d.getAttribute("name");
        before = Strings.trim(d.getAttribute("before"));
        Element lbl = DOMUtil.getLocalizedUniqueTag(d, "label", locale);
        if (lbl!=null) {
            label = DOMUtil.getElementString(lbl);
            String mn = lbl.getAttribute("mnemonic");
            if (mn!=null && mn.length()>0)
                mnemonic = mn.charAt(0);
        }
    }
    /***PopupMenuDescription***************************/
    protected Container getMenu(Container c) {
        JMenu menu = (JMenu)findChild(c, name);
        if (menu==null) {
            menu = new JMenu(label);
            menu.putClientProperty(ButtonDescription.NAME, name);
            if (mnemonic!=0)
                menu.setMnemonic(mnemonic);
            int bidx = before==null ? -1 : findChildIndex(c, before);
            c.add(menu, bidx);
        }
        menu.getPopupMenu().putClientProperty(MENU, menu);
        return menu.getPopupMenu();
    }
}
