/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: AbstractTableCellRenderer.java,v 1.4 2001/08/20 09:23:39 max Exp $
 *
 */

package make.swing.cell;

import java.awt.Component;
import javax.swing.JTable;
import javax.swing.table.TableCellRenderer;

public abstract class AbstractTableCellRenderer 
    implements CellRenderer, TableCellRenderer {
    /***properties**************************/
    protected TableCellRenderer parent;
    private JTable currentTable;
    private int currentRow, currentColumn;
    /***Constructor*************************/
    public AbstractTableCellRenderer(TableCellRenderer _p) {
	parent = _p;
    }
    /***AbstractTableCellRenderer*********/
    protected CellRenderer getCellRenderer(int row, int column) {
	return null;
    }
    /***CellRenderer***************************/
    public Component getCellRendererComponent(Object value,
					      boolean isSelected, 
					      boolean hasFocus) {
	return parent.getTableCellRendererComponent
	    (currentTable, value, isSelected, hasFocus,
	     currentRow, currentColumn);
    }
    /***TableCellRenderer************************/
    public synchronized Component getTableCellRendererComponent(JTable table,
								Object value,
								boolean isSelected,
								boolean hasFocus,
								int row,
								int column) {
	CellRenderer cr = getCellRenderer(row, column);
	if (cr==null) {
	    return parent.getTableCellRendererComponent
		(table, value, isSelected, hasFocus,
		 row, column);
	} else {
	    try {
		currentTable = table;
		currentRow = row;
		currentColumn = column;
		return cr.getCellRendererComponent
		    (value, isSelected, hasFocus);
	    } finally {
		currentTable = null;
	    }
	}
    }   
}
