/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: CheckBoxField.java,v 1.6 2001/12/14 07:34:08 max Exp $
 *
 */

package make.swing.field;

import java.awt.event.ActionEvent;
import java.text.ParseException;
import javax.swing.JCheckBox;

public class CheckBoxField extends DefaultField {
    /***properties****************************/
    protected JCheckBox checkBox;
    protected Object trueValue, falseValue;
    /***Constructor***************************/
    public CheckBoxField(String text, Object _tv, Object _fv) {
        checkBox = new JCheckBox(text);
        checkBox.addActionListener(this);
        setComponent(checkBox);
        trueValue = _tv;
        falseValue = _fv;
    }
    public CheckBoxField(String text) {
        this(text, "yes", "no");
    }
    /***Slot********************************/
    public void setValue(Object v) throws ParseException {
        if (trueValue.equals(v))
            checkBox.setSelected(true);
        else if (falseValue.equals(v))
            checkBox.setSelected(false);
        else
            throw new ParseException("unknown checkbox value: "+v, 0);
    }
    public Object getValue() throws ParseException {
        return checkBox.isSelected() ? trueValue : falseValue;
    }
    /***Widget****************************/
    public void setEnabled(boolean _e) {
        checkBox.setEnabled(_e);
    }
    public boolean getEnabled() {
        return checkBox.isEnabled();
    }
    public void dispose() {
        checkBox.removeActionListener(this);
        super.dispose();
    }
    /***ActionListener*********************/
    public void actionPerformed(ActionEvent evt) {
        fireValueChanged();
        super.actionPerformed(evt);
    }
}
