/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: ComboField.java,v 1.4 2001/08/20 09:23:39 max Exp $
 *
 */

package make.swing.field;

import java.awt.Component;
import java.awt.event.ActionEvent;
import java.util.Vector;
import java.text.ParseException;
import javax.swing.JComboBox;
import javax.swing.ListCellRenderer;
import javax.swing.JList;
import make.util.Strings;
import make.util.Debug;

public class ComboField extends DefaultField 
    implements ListCellRenderer {
    /***properties**************************/
    protected JComboBox component;
    protected Object[] list, translate;
    protected ListCellRenderer renderer;
    /***Constructor************************/
    public ComboField(Vector list, boolean _editable) {
	component = new JComboBox(list);
	component.addActionListener(this);
	component.setEditable(_editable);
	setComponent(component);
    }
    public ComboField(Object[] _list, Object[] _translate, boolean _editable) {
	list = _list; translate = _translate;
	if (translate!=null && translate.length==0)
	    translate = null;
	component = new JComboBox(translate==null?list:translate);
	component.addActionListener(this);
	component.setEditable(_editable);
	if (translate!=null) {
	    renderer = component.getRenderer();
	    component.setRenderer(this);
	}
	setComponent(component);
	if (Debug.DEBUG && translate!=null && translate.length!=list.length) {
	    System.err.println("WARNING: check length of translate list");
	    translate = null;
	}
    }
    public ComboField(Object[] _list, boolean _editable) {
	this(_list, null, _editable);
    }
    /***ListCellRenderer*************************/
    public Component getListCellRendererComponent(JList _list, Object value,
						  int index,
						  boolean isSelected,
						  boolean cellHasFocus) {
	if (translate!=null && value!=null)
	    value = Strings.translate(translate, list, value);
	return renderer.getListCellRendererComponent(_list, value, index,
						     isSelected, cellHasFocus);
    }
    /***Field*******************************/
    public void setValue(Object v) throws ParseException {
	if (v!=null && translate!=null) {
	    Object v2 = Strings.translate(translate, list, v);
	    if (v2==null)
		throw new ParseException(null, 0); //TODO
	}
	component.setSelectedItem(v);
    }
    public Object getValue() throws ParseException {
	return component.getSelectedItem();
    }
    public void setEnabled(boolean _e) {
	component.setEnabled(_e);
    }
    public boolean getEnabled() {
	return component.isEnabled();
    }
    /***ActionListener*********************/
    public void actionPerformed(ActionEvent evt) {
	fireValueChanged();
	super.actionPerformed(evt);
    }    
}
