/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: DefaultField.java,v 1.7 2001/12/17 10:14:19 max Exp $
 *
 */

package make.swing.field;

import java.awt.Component;
import java.awt.event.FocusListener;
import java.awt.event.FocusEvent;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.util.Vector;
import java.util.Enumeration;
import java.util.ResourceBundle;
import make.util.Resources;
import make.swing.ButtonManager;

public abstract class DefaultField 
    implements Field, FocusListener, ActionListener {
    /*static******************************/
    public static final ResourceBundle messages
        = Resources.getResourceBundle(DefaultField.class.getClassLoader(),
                                      "make.swing.field.ParseMessages");
    /*properties**************************/
    private Vector listeners = new Vector();
    private Component component;
    /*Constructor*************************/
    public DefaultField() {}
    public DefaultField(Component _c) {
        setComponent(_c);
    }
    /*DefaultField***********************/
    protected void setComponent(Component _c) {
        if (component!=null)
            component.removeFocusListener(this);
        component = _c;
        if (component!=null)
            component.addFocusListener(this);
    }
    public void fireValueChanged() {
        FieldEvent evt = new FieldEvent(this);
        for (Enumeration enum=listeners.elements(); enum.hasMoreElements();)
            ((FieldListener)enum.nextElement()).valueChanged(evt);
    }
    public void fireFocusGained() {
        FieldEvent evt = new FieldEvent(this);
        for (Enumeration enum=listeners.elements(); enum.hasMoreElements();)
            ((FieldListener)enum.nextElement()).focusGained(evt);
    }
    public void fireFocusLost() {
        FieldEvent evt = new FieldEvent(this);
        for (Enumeration enum=listeners.elements(); enum.hasMoreElements();)
            ((FieldListener)enum.nextElement()).focusLost(evt);
    }
    public void fireActionPerformed() {
        FieldEvent evt = new FieldEvent(this);
        for (Enumeration enum=listeners.elements(); enum.hasMoreElements();)
            ((FieldListener)enum.nextElement()).actionPerformed(evt);
    }
    /*Widget**************************/
    public Component getComponent() { 
        return component; 
    }
    public void dispose() {
        setComponent(null);
        listeners = null;
    }
    /*Field*****************************/
    public void install(ButtonManager bm) {}
    public void uninstall(ButtonManager bm) {}
    public void addFieldListener(FieldListener _l) {
        listeners.addElement(_l);
    }
    public void removeFieldListener(FieldListener _l) {
        listeners.removeElement(_l);
    }
    /*FocusListener************************/
    public void focusGained(FocusEvent evt) {
        if (!evt.isTemporary())
            fireFocusGained();
    }
    public void focusLost(FocusEvent evt) {
        if (!evt.isTemporary())
            fireFocusLost();
    }
    /*ActionListener************************/
    public void actionPerformed(ActionEvent evt) {
        fireActionPerformed();
    }
}
