/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: FieldCellEditor.java,v 1.4 2001/08/20 09:23:39 max Exp $
 *
 */

package make.swing.field;

import java.util.Vector;
import java.util.Enumeration;
import java.util.EventObject;
import java.awt.Component;
import java.text.ParseException;
import javax.swing.JOptionPane;
import javax.swing.CellEditor;
import javax.swing.event.CellEditorListener;
import javax.swing.event.ChangeEvent;

public class FieldCellEditor implements CellEditor {
    /***properties***************************/
    protected Vector listeners = new Vector();
    protected Field field;
    protected Object value;
    /***Fire*******************************/
    protected void fireEditingStopped() {
	ChangeEvent evt = new ChangeEvent(this);
	for (Enumeration enum=listeners.elements(); enum.hasMoreElements();)
	    ((CellEditorListener)enum.nextElement()).editingStopped(evt);
    }
    protected void fireEditingCanceled() {
	ChangeEvent evt = new ChangeEvent(this);
	for (Enumeration enum=listeners.elements(); enum.hasMoreElements();)
	    ((CellEditorListener)enum.nextElement()).editingCanceled(evt);
    }
    protected Component getComponent(Field _f, Object _value,
				     boolean isSelected) {
	field = _f; value = _value;
	try {
	    field.setValue(value);
	} catch (ParseException e) {
	    try {
		field.setValue(null);
	    } catch (ParseException e2) {
	    }
	}
	return field.getComponent();
    }
    /***CellEditor**************************/
    public Object getCellEditorValue() {
	return value;
    }
    public boolean isCellEditable(EventObject evt) {
	return true;
    }
    public boolean shouldSelectCell(EventObject anEvent) {
	return true;
    }
    public boolean stopCellEditing() {
	try {
	    value = field==null
		?null
		:field.getValue();
	    field = null;
	    fireEditingStopped();
	    return true;
	} catch (ParseException e) {
	    JOptionPane.showMessageDialog
		(null, e.getLocalizedMessage(), 
		 "Eingabefehler", JOptionPane.ERROR_MESSAGE);
	    return false;
	}
    }
    public void cancelCellEditing() {
	fireEditingCanceled();
    }
    public void addCellEditorListener(CellEditorListener l) {
	listeners.addElement(l);
    }
    public void removeCellEditorListener(CellEditorListener l) {
	listeners.addElement(l);
    }
}
