/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: IntegerField.java,v 1.3 2001/08/20 09:23:39 max Exp $
 *
 */

package make.swing.field;

import java.text.ParseException;
import java.text.NumberFormat;
import make.util.Strings;

public class IntegerField extends TextField {
    /***properties**************************/
    protected NumberFormat storeFormat, displayFormat;
    /***Constructor**************************/
    public IntegerField(boolean storeString) {
	storeFormat = storeString?Strings.storeIntegerFormat:null;
	displayFormat = Strings.displayIntegerFormat;
    }
    public IntegerField(NumberFormat sf, NumberFormat df) {
	storeFormat = sf;
	displayFormat = df;
    }
    /***Field******************************/
    public Object getValue() throws ParseException {
	String s = (String)super.getValue();
	if (s==null)
	    return null;
	try {
	    Number v = displayFormat.parse(s);
	    return storeFormat==null
		?(Object)new Integer(v.intValue())
		:storeFormat.format(v);
	} catch (ParseException e) {
	    throw new ParseException(messages.getString("error.integer"), 0);
	}
    }
    public void setValue(Object _v) throws ParseException {
	if (_v==null)
	    super.setValue(_v);
	else {
	    Number v;
	    if (_v instanceof String)
		v = storeFormat.parse((String)_v);
	    else
		v = (Number)_v;
	    super.setValue(displayFormat.format(v));
	}
    }
}
