/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: PasswordField.java,v 1.4 2001/08/20 09:23:39 max Exp $
 *
 */

package make.swing.field;

import java.awt.Component;
import java.awt.event.ActionListener;
import java.text.ParseException;
import javax.swing.JPasswordField;
import javax.swing.event.DocumentListener;
import javax.swing.event.DocumentEvent;
import make.swing.GenericButton;
import make.swing.ButtonManager;

public class PasswordField extends DefaultField implements DocumentListener {
    /***properties**************************/
    protected JPasswordField component;
    protected final GenericButton defaultButton = new GenericButton() {
	    public Object getActionSource() { return component; }
	    public String getActionCommand() { return "ok"; }
	    public void addActionListener(ActionListener al) {
		component.addActionListener(al);
	    }
	    public void removeActionListener(ActionListener al) {
		component.removeActionListener(al);
	    }
	    public void setEnabled(boolean _e) {}
	    public void setSelected(boolean _p) {}
	};
    /***Constructor************************/
    public PasswordField(int len) {
	component = new JPasswordField(len);
	component.addActionListener(this);
	component.getDocument().addDocumentListener(this);
	setComponent(component);
    }
    public PasswordField() {
	this(10);
    }
    /***Field*******************************/
    public void install(ButtonManager bm) {
	super.install(bm);
	bm.installButton(defaultButton);
    }
    public void uninstall(ButtonManager bm) {
	bm.uninstallButton(defaultButton);
	super.uninstall(bm);
    }
    public void setValue(Object v) throws ParseException {
	component.setText(v==null?"":(String)v);
    }
    public Object getValue() throws ParseException {
	return new String(component.getPassword());
    }
    public void setEnabled(boolean _e) {
	component.setEnabled(_e);
    }
    public boolean getEnabled() {
	return component.isEnabled();
    }
    /***DocumentListener*********************/
    public void insertUpdate(DocumentEvent e) {
	fireValueChanged();
    }    
    public void removeUpdate(DocumentEvent e) {
	fireValueChanged();
    }    
    public void changedUpdate(DocumentEvent e) {
	fireValueChanged();
    }    
}
