/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: SelectField.java,v 1.8 2001/08/20 09:23:39 max Exp $
 *
 */

package make.swing.field;

import java.util.Map;
import java.util.Collection;
import java.awt.Component;
import java.awt.event.ActionEvent;
import java.text.ParseException;
import javax.swing.JComboBox;
import javax.swing.ListCellRenderer;
import javax.swing.JList;

public class SelectField extends DefaultField 
    implements ListCellRenderer {
    /***properties**************************/
    protected final Object nullValue = this;
    protected JComboBox component;
    protected Map map;
    protected ListCellRenderer renderer;
    /***Constructor************************/
    public SelectField(Map _map) {
	map = _map;
	Object[] list = map==null
	    ? new Object[]{}
	    : map.keySet().toArray();
	for (int z=0; z<list.length; z++) {
	    // translate null values to go around bugs in swing
	    if (list[z]==null)
		list[z] = nullValue;
	}
	component = new JComboBox(list);
	component.addActionListener(this);
	component.setEditable(false);
	renderer = component.getRenderer();
	component.setRenderer(this);
	setComponent(component);
    }
    public SelectField(Collection c) {
	Object[] list = c==null
	    ? new Object[]{}
	    : c.toArray();
	for (int z=0; z<list.length; z++) {
	    // translate null values to go around bugs in swing
	    if (list[z]==null)
		list[z] = nullValue;
	}
	component = new JComboBox(list);
	component.addActionListener(this);
	component.setEditable(false);
	renderer = component.getRenderer();
	component.setRenderer(this);
	setComponent(component);
    }
    /***ListCellRenderer*************************/
    public Component getListCellRendererComponent(JList _list, Object value,
						  int index,
						  boolean isSelected,
						  boolean cellHasFocus) {
	if (value==nullValue)
	    value = null;
	Object vDisplay;
	if (map==null)
	    vDisplay = value;
	else
	    vDisplay = map.get(value);
	if (vDisplay==null)
	    vDisplay = value;
	return renderer.getListCellRendererComponent
	    (_list, vDisplay, index,
	     isSelected, cellHasFocus);
    }
    /***Field*******************************/
    public void setValue(Object v) throws ParseException {
	if (v==null) v = nullValue;
	component.setSelectedItem(v);
    }
    public Object getValue() throws ParseException {
	Object v = component.getSelectedItem();
	return v==nullValue ? null : v;
    }
    public void setEnabled(boolean _e) {
	component.setEnabled(_e);
    }
    public boolean getEnabled() {
	return component.isEnabled();
    }
    /***ActionListener*********************/
    public void actionPerformed(ActionEvent evt) {
	fireValueChanged();
	super.actionPerformed(evt);
    }    
}
