/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: TextAreaField.java,v 1.2 2002/01/03 11:32:41 max Exp $
 *
 */

package make.swing.field;

import java.awt.Component;
import java.text.ParseException;
import javax.swing.JTextArea;
import javax.swing.event.DocumentListener;
import javax.swing.event.DocumentEvent;
import make.util.Strings;

public class TextAreaField
    extends DefaultField
    implements DocumentListener {
    /*properties**************************/
    protected JTextArea component;
    /*Constructor************************/
    public TextAreaField(int rows, int columns) {
        component = new JTextArea(rows, columns);
        component.getDocument().addDocumentListener(this);
        setComponent(component);
    }
    /*Widget**********************/
    public void setEnabled(boolean _e) {
        component.setEditable(_e);
    }
    public boolean getEnabled() {
        return component.isEditable();
    }
    public void dispose() {
        component.getDocument().removeDocumentListener(this);
        super.dispose();
    }
    /*Field*******************************/
    public void setValue(Object v) throws ParseException {
        component.setText(v==null?"":(String)v);
    }
    public Object getValue() throws ParseException {
        return Strings.trim(component.getText());
    }
    /*DocumentListener*********************/
    public void insertUpdate(DocumentEvent e) {
        fireValueChanged();
    }    
    public void removeUpdate(DocumentEvent e) {
        fireValueChanged();
    }    
    public void changedUpdate(DocumentEvent e) {
        fireValueChanged();
    }    
}
