/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: TextField.java,v 1.6 2001/08/20 09:23:39 max Exp $
 *
 */

package make.swing.field;

import java.awt.Component;
import java.awt.event.ActionListener;
import java.text.ParseException;
import javax.swing.JTextField;
import javax.swing.event.DocumentListener;
import javax.swing.event.DocumentEvent;
import make.util.Debug;
import make.util.Strings;
import make.swing.ButtonManager;
import make.swing.TextButton;

public class TextField extends DefaultField implements DocumentListener {
    /*properties**************************/
    protected JTextField component;
    protected TextButton textButton;
    protected String command = "ok";
    /*Constructor************************/
    public TextField(int len) {
	component = new JTextField(len);
	component.addActionListener(this);
	component.getDocument().addDocumentListener(this);
	setComponent(component);
    }
    public TextField() {
	this(20);
    }
    public void setActionCommand(String _cmd) {
	if (Debug.DEBUG && textButton!=null)
	    throw new InternalError("please call setActionCommand before install");
	command = _cmd;
    }
    /*Widget**********************/
    public void setEnabled(boolean _e) {
	component.setEditable(_e);
    }
    public boolean getEnabled() {
	return component.isEditable();
    }
    public void dispose() {
	component.getDocument().removeDocumentListener(this);
	component.removeActionListener(this);
	super.dispose();
    }
    /*Field*******************************/
    public void install(ButtonManager bm) {
	super.install(bm);
	if (textButton==null)
	    textButton = new TextButton(component, command);
	bm.installButton(textButton);
    }
    public void uninstall(ButtonManager bm) {
	if (textButton!=null)
	    bm.uninstallButton(textButton);
	super.uninstall(bm);
    }
    public void setValue(Object v) throws ParseException {
	component.setText(v==null?"":(String)v);
    }
    public Object getValue() throws ParseException {
	return Strings.trim(component.getText());
    }
    /*DefaultField**************************/
    public void fireFocusGained() {
	super.fireFocusGained();
	component.selectAll();
    }
    /*DocumentListener*********************/
    public void insertUpdate(DocumentEvent e) {
	fireValueChanged();
    }    
    public void removeUpdate(DocumentEvent e) {
	fireValueChanged();
    }    
    public void changedUpdate(DocumentEvent e) {
	fireValueChanged();
    }    
}
