/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: TranslateTextField.java,v 1.6 2001/08/20 09:23:39 max Exp $
 *
 */

package make.swing.field;

import java.util.Map;
import java.text.ParseException;

public class TranslateTextField extends TextField {
    /***properties**************************/
    protected Map map;
    protected Object value, displayValue;
    protected boolean editing = false;
    protected boolean changed = false;
    /***Constructor************************/
    public TranslateTextField(int len, Map _map) {
	super(len);
	map = _map;
    }
    public TranslateTextField(Map _map) {
	this(20, _map);
    }
    /***DefaultField**********************/
    public void fireValueChanged() {
	super.fireValueChanged();
	changed = true;
    }
    public void fireFocusGained() {
	super.fireFocusGained();
	try {
	    editing = true;
	    super.setValue(value);
	    component.selectAll();
	} catch (ParseException e) {
	}
    }
    public void fireFocusLost() {
	super.fireFocusLost();
	try {
	    sync();
	    editing = false;
	    super.setValue(displayValue);
	} catch (ParseException e) {
	}
    }
    /***Internal****************************/
    protected void sync() {
	if (changed) {
	    if (editing)
		try {
		    value = super.getValue();
		} catch (ParseException e) {
		    value = null;
		}
	    displayValue = map.get(value);
	    if (displayValue==null) {
		if (value instanceof String) {
		    String v2 = ((String)value).toUpperCase();
		    displayValue = map.get(v2);
		    if (displayValue==null) {
			v2 = ((String)value).toLowerCase();
			displayValue = map.get(v2);
			if (displayValue==null)
			    displayValue = value;
			else
			    value = v2;
		    } else
			value = v2;
		} else
		    displayValue = value;
	    }
	    changed = false;
	}
    }
    /***Field*******************************/
    public void setValue(Object v) throws ParseException {
	value = v;
	changed = true;
	if (editing) {
	    super.setValue(value);
	} else {
	    sync();
	    super.setValue(displayValue);
	}
    }
    public Object getValue() throws ParseException {
	sync();
	return value;
    }
}
