/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: ContainerInputLink.java,v 1.6 2001/12/20 16:49:08 max Exp $
 *
 */

package make.swing.il;

import java.util.Vector;
import java.util.Enumeration;
import java.util.Locale;
import java.text.ParseException;
import java.awt.Component;
import javax.swing.JLabel;
import org.w3c.dom.Element;
import make.swing.ButtonManager;

/**
 * ContainerInputLink is a default implementation of
 * CompositeInputLink. 
 * It automatically handles the distributions of the basic
 * InputLink calls to its children.
 */
public abstract class ContainerInputLink extends DefaultInputLink
    implements CompositeInputLink {
    /*properties*****************/
    protected Vector fields = new Vector();
    protected boolean enabled = true;
    /*Constructor****************/
    public ContainerInputLink(Element vd, Locale locale) {
        super(vd, locale);
    }
    public ContainerInputLink() {
        this(null, null);
    }
    private void parseException(InputLink il, ParseException e) 
        throws ParseException {
        if (il instanceof CompositeInputLink)
            throw e;
        else {
            il.getComponent().requestFocus();
            Component lbl = il.getLabel();
            if (lbl instanceof JLabel)
		// FIXME: i18n
                throw new ParseException
                    ("Eingabefehler im Feld "+((JLabel)lbl).getText()+'\n'+
                     e.getLocalizedMessage(), 0);
            else
                throw e;
        }
    }
    /*Widget******************************/
    public void install(ButtonManager bm) {
        super.install(bm);
        for (Enumeration enum=fields.elements();enum.hasMoreElements();)
            ((InputLink)enum.nextElement()).install(bm);
    }
    public void uninstall(ButtonManager bm) {
        for (Enumeration enum=fields.elements();enum.hasMoreElements();)
            ((InputLink)enum.nextElement()).uninstall(bm);
        super.uninstall(bm);
    }
    public void setEnabled(boolean _e) {
        for (Enumeration enum=fields.elements(); enum.hasMoreElements();)
            ((InputLink)enum.nextElement()).setEnabled(_e);
        enabled = _e;
    }
    public boolean getEnabled() {
        return enabled;
    }
    public void dispose() {
        for (Enumeration enum=fields.elements(); enum.hasMoreElements();)
            ((InputLink)enum.nextElement()).dispose();
        super.dispose();
    }
    /*InputLink*************************/
    public void reload() {
        for (Enumeration enum=fields.elements(); enum.hasMoreElements();) {
            InputLink il = (InputLink)enum.nextElement();
            il.reload();
        }
    }
    public void apply() throws ParseException {
        for (Enumeration enum=fields.elements(); enum.hasMoreElements();) {
            InputLink il = (InputLink)enum.nextElement();
            try {
                il.apply();
            } catch (ParseException e) {
                parseException(il, e);
            }
        }
    }
    public void checkInput() throws ParseException {
        for (Enumeration enum=fields.elements(); enum.hasMoreElements();) {
            InputLink il = (InputLink)enum.nextElement();
            try {
                il.checkInput();
            } catch (ParseException e) {
                parseException(il, e);
            }
        }
    }
    /*CompositeInputLink*******************/
    public Enumeration getInputLinks() {
        return fields.elements();
    }
}
