/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: InputLink.java,v 1.5 2001/08/20 09:23:39 max Exp $
 *
 */

package make.swing.il;

import java.awt.Component;
import java.text.ParseException;
import make.swing.Widget;
import make.swing.ButtonManager;

/**
 * An InputLink is an object which can load data
 * from a data source, lets the user do some input, 
 * and write the modified data back to the data source.
 */
public interface InputLink extends Widget {
    /**
     * tells the object to install its actions and buttons
     * in the specified ButtonManager object
     */
    void install(ButtonManager bm);
    /**
     * tells the object to uninstall its actions and buttons
     * in the specified ButtonManager object
     */
    void uninstall(ButtonManager bm);
    /**
     * returns the label Component object of this InputLink.
     */
    Component getLabel();
    /**
     * Reloads all data from the data source 
     * and displays the changed data on the screen.
     */
    void reload();
    /**
     * Saves all displayed data into the data source.
     */
    void apply() throws ParseException;
    /**
     * Asks the data source about the validity of the current input.
     */
    void checkInput() throws ParseException;
}
