/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: PanelInputLink.java,v 1.8 2001/12/20 16:49:08 max Exp $
 *
 */

package make.swing.il;

import java.util.Locale;
import java.awt.Component;
import java.awt.GridBagLayout;
import java.awt.GridBagConstraints;
import javax.swing.JPanel;
import org.w3c.dom.Element;
import make.xml.DOMUtil;

public class PanelInputLink extends ContainerInputLink {
    /*static*****************/
    public static final GridBagConstraints labelConstraints
        = new GridBagConstraints();
    public static final GridBagConstraints fieldConstraints
        = new GridBagConstraints();
    public static final GridBagConstraints verticalConstraints
        = new GridBagConstraints();
    public static final GridBagLayout gridBagLayout
        = new GridBagLayout();
    static {
        labelConstraints.fill = labelConstraints.HORIZONTAL;
        fieldConstraints.fill = fieldConstraints.BOTH;
        fieldConstraints.gridwidth = fieldConstraints.REMAINDER;
        fieldConstraints.weightx = 1.0;
        verticalConstraints.fill = fieldConstraints.BOTH;
        verticalConstraints.gridwidth = fieldConstraints.REMAINDER;
        verticalConstraints.weightx = 1.0;
        verticalConstraints.weighty = 1.0;
    }
    /*properties*****************/
    protected JPanel panel = new JPanel(gridBagLayout, false);
    /*Constructor****************/
    public PanelInputLink(Element vd, Element[] fsa, Locale locale,
                          InputLinkFactory ilf) {
        super(vd, locale);
        for (int z=0; z<fsa.length; z++) {
            InputLink il = ilf.createInputLink(fsa[z], locale);
            if (il!=null) {
                fields.addElement(il);
                Component label = il.getLabel();
                if (label!=null)
                    panel.add(label, labelConstraints);
                Component component = il.getComponent();
                panel.add(component, getConstraints(fsa[z]));
            }
        }
    }
    protected Object getConstraints(Element vd) {
        String cs = DOMUtil.getElementStringNS
            (vd, InputLinkFactory.XML_NAMESPACE, "constraints");
        if (cs==null)
            vd.getAttributeNS(InputLinkFactory.XML_NAMESPACE, "constraints");
        if ("vertical".equals(cs))
            return verticalConstraints;
        else
            return fieldConstraints;
    }
    /*InputLink*************************/
    public Component getComponent() { return panel; }
}
