/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: ProxyInputLink.java,v 1.1 2001/12/19 16:57:42 max Exp $
 *
 */

package make.swing.il;

import java.awt.Component;
import java.text.ParseException;
import make.swing.Widget;
import make.swing.ButtonManager;

public class ProxyInputLink implements InputLink {
    /*properties********************/
    protected InputLink original;

    /*Constructor*******************/
    public ProxyInputLink(InputLink _org) {
        original = _org;
    }
    public void setInputLink(InputLink _org) {
        original = _org;
    }

    /*Widget*************************/
    public void setEnabled(boolean _e) {
        if (original!=null)
            original.setEnabled(_e);
    }
    public boolean getEnabled() {
        return original==null
            ? true : original.getEnabled();
    }
    public Component getComponent() {
        // returning null here is illegal..
        if (original==null)
            throw new IllegalStateException("original==null");
        return original.getComponent();
    }
    public void dispose() {
        if (original!=null) {
            original.dispose();
            original = null;
        }
    }

    /*InputLink***********************/
    public void install(ButtonManager bm) {
        if (original!=null)
            original.install(bm);
    }
    public void uninstall(ButtonManager bm) {
        if (original!=null)
            original.uninstall(bm);
    }
    public Component getLabel() {
        return original==null
            ? null : original.getLabel();
    }
    public void reload() {
        if (original!=null)
            original.reload();
    }
    public void apply() throws ParseException {
        if (original!=null)
            original.apply();
    }
    public void checkInput() throws ParseException {
        if (original!=null)
            original.checkInput();
    }
}
