/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: ContainerInterfacePanel.java,v 1.1 2001/10/12 20:01:55 max Exp $
 *
 */

package make.swing.panel;

import java.awt.Frame;
import java.awt.Component;
import java.awt.Container;
import java.awt.event.ActionEvent;
import javax.swing.Action;
import javax.swing.AbstractAction;
import make.swing.ButtonManager;
import make.swing.bt.FrameDescription;
import make.swing.bt.ButtonContainer;
import make.swing.bt.ButtonDescription;

public class ContainerInterfacePanel 
    implements InterfacePanel, ButtonContainer {
    /*properties********************************/
    private ButtonManager buttonManager = new ButtonManager();
    protected Frame frame;
    protected Container container;
    protected Object constraints;
    protected PanelContent content;
    protected Component component;
    protected boolean visible = false;
    /*Constructor**********************************/
    public ContainerInterfacePanel(Frame _f, Container _container,
				   Object _constraints) {
	frame = frame;
	container = _container;
	constraints = _constraints;
	buttonManager.installActions(getActions());
    }
    /*Internal***************************************/
    public PanelContent getContent() { return content; }
    /*InterfacePanel******************************/
    public void setContent(PanelContent c) {
	if (component!=null) {
	    container.remove(component);
	    component.setVisible(true);
	    component = null;
	}
	content = c;
	if (content!=null) {
	    component = content.getComponent();
	    if (component!=null) {
		component.setVisible(visible);
		container.add(component, constraints);
	    }
	}
	container.validate();
    }
    public void addFrameDescription(FrameDescription fd) {}
    public void removeFrameDescription(FrameDescription fd) {}
    public ButtonContainer getButtonContainer() {
	return this;
    }
    public ButtonManager getButtonManager() {
	return buttonManager;
    }
    public void setTitle(String s) {}
    public Frame getFrame() {
	return frame;
    }
    public void setVisible(boolean _visible) {
	if (_visible==visible)
	    return;
	visible = _visible;
	if (component!=null)
	    component.setVisible(_visible);
    }
    public void close() {
	if (content!=null) {
	    content.panelClosed();
	    setContent(null);
	}
	buttonManager.uninstallActions(getActions());
	buttonManager.dispose();
	buttonManager = null;
    }
    /*ButtonContainer********************************/
    public ButtonDescription getButton(String name) {
	return null; //TODO
    }
    /*Actions*******************************************/
    protected Action[] getActions() {
	return defaultActions; //TODO: parent
    }
    protected Action[] defaultActions = {
	new CloseFrameAction(),
    };
    class CloseFrameAction extends AbstractAction {
	CloseFrameAction() { super("close-frame"); }
        public void actionPerformed(ActionEvent evt) {
	    PanelContent content = getContent();
	    if (content==null || content.panelClosing())
		close();
	}
    }
}
