/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: InternalFrameInterfacePanel.java,v 1.1 2001/10/12 20:01:55 max Exp $
 *
 */

package make.swing.panel;

import java.awt.Frame;
import java.awt.event.ActionEvent;
import javax.swing.JInternalFrame;
import javax.swing.Action;
import javax.swing.AbstractAction;
import javax.swing.JMenuBar;
import javax.swing.event.InternalFrameListener;
import javax.swing.event.InternalFrameEvent;
import make.swing.bt.FrameDescription;

public class InternalFrameInterfacePanel 
    extends AbstractInterfacePanel 
    implements InternalFrameListener {
    /*properties********************************/
    protected String title, fileName;
    protected JInternalFrame frame
	= new JInternalFrame(null, true, true, true, true);
    protected DesktopPanelContent desktop;
    protected boolean shown = false;
    /*Constructor**********************************/
    public InternalFrameInterfacePanel(DesktopPanelContent _d) {
	desktop = _d;
	frame.setDefaultCloseOperation(frame.DO_NOTHING_ON_CLOSE);
	frame.addInternalFrameListener(this);
	initialize(desktop.getFrame(), frame, frame.getContentPane());
	getButtonManager().installActions(getActions());
    }
    /*Internal***************************************/
    protected void updateTitle() {
	if (fileName==null)
	    frame.setTitle(title);
	else if (title==null)
	    frame.setTitle(fileName);
	else
	    frame.setTitle(fileName+" - "+title);
    }
    /*AbstractInterfacePanel****************************/
    protected void setMenuBar(JMenuBar mb) {
	frame.setJMenuBar(mb);
	frame.validate();
    }
    /*InterfacePanel******************************/
    public void setContent(PanelContent c) {
	super.setContent(c);
	if (c!=null)
	    frame.pack();
    }
    public void addFrameDescription(FrameDescription fd) {
	super.addFrameDescription(fd);
	String t = fd.getTitle();
	if (t!=null) {
	    title = t;
	    updateTitle();
	}
    }
    public void setTitle(String s) { 
	fileName = s; updateTitle();
    }
    public void setVisible(boolean _visible) {
	if (_visible && packIt) {
	    frame.pack();
	    desktop.addFrame(this);
	    frame.toFront();
	    shown = true;
	    packIt = false;
	}
	frame.setVisible(_visible);
	updateFocus();
    }
    public void close() {
	if (shown) {
	    desktop.removeFrame(this);
	    shown = false;
	}
	frame.removeInternalFrameListener(this);
	frame.dispose();
	getButtonManager().uninstallActions(getActions());
	super.close();
    }
    /*InternalFrameListener***************************/
    public void internalFrameOpened(InternalFrameEvent e) {}
    public void internalFrameClosing(InternalFrameEvent e) {
	PanelContent content = getContent();
	if (content==null || content.panelClosing())
	    close();
    }
    public void internalFrameClosed(InternalFrameEvent e) {
	PanelContent content = getContent();
	if (content!=null)
	    content.panelClosed();
    }
    public void internalFrameIconified(InternalFrameEvent e) {}
    public void internalFrameDeiconified(InternalFrameEvent e) {}
    public void internalFrameActivated(InternalFrameEvent e) {}
    public void internalFrameDeactivated(InternalFrameEvent e) {}
    /*Actions*******************************************/
    protected Action[] getActions() {
	return defaultActions; //TODO: parent
    }
    protected Action[] defaultActions = {
	new CloseFrameAction(),
    };
    class CloseFrameAction extends AbstractAction {
	CloseFrameAction() { super("close-frame"); }
        public void actionPerformed(ActionEvent evt) {
	    PanelContent content = InternalFrameInterfacePanel.this.getContent();
	    if (content==null || content.panelClosing())
		close();
	}
    }
    /*InternalFrameInterfacePanel******************************/
    public JInternalFrame getInternalFrame() { return frame; }
}
