/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: ContainerProgressIndicatorFactory.java,v 1.2 2001/08/20 09:23:39 max Exp $
 *
 */

package make.swing.progress;

import java.awt.Component;
import java.awt.Container;
import make.swing.StatusWindow;

public class ContainerProgressIndicatorFactory
    implements ProgressIndicatorFactory {
    public class ContainerStatus extends StatusWindow {
	protected Component panel;
	public ContainerStatus(String _text, String _title, int _wait, 
			       boolean _cancel, Thread _jobThread) {
	    super(_text, _title, _wait, _cancel, _jobThread);
	}
	public ContainerStatus(String _text, String _title, int _wait, 
			       boolean _cancel) {
	    super(_text, _title, _wait, _cancel);
	}
	protected void createFrame() {
	    panel = createPanel();
	    container.add(panel, constraints);
	    container.validate();
	}
	public void run() {
	    try {
		super.run();
	    } finally {
		if (panel!=null) {
		    container.remove(panel);
		    container.validate();
		}
	    }
	}
    }
    /*properties************************/
    protected Container container;
    protected Object constraints;
    /*Constructor**********************/
    public ContainerProgressIndicatorFactory(Container _container, 
					 Object _constraints) {
	container = _container;
	constraints = _constraints;
    }
    /*ProgressIndicatorFactory***************/
    public ProgressIndicator create(String text, String title, 
				    boolean cancelButton, Thread job) {
	if (job==null)
	    return new ContainerStatus(text, title, 100,
				       cancelButton);
	else
	    return new ContainerStatus(text, title, 100,
				       cancelButton, job);
    }
}
