/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: Document.java,v 1.5 2001/08/20 09:23:39 max Exp $
 *
 */

package make.swing.text;

import java.util.Hashtable;
import javax.swing.event.UndoableEditListener;
import javax.swing.undo.UndoableEdit;
import javax.swing.text.Segment;
import javax.swing.text.Position;
import javax.swing.text.BadLocationException;

public interface Document {
    // event
    void addDocumentListener(DocumentListener listener);
    void removeDocumentListener(DocumentListener listener);
    void fireDocumentChanged(DocumentEvent evt);
    DocumentEvent getUndoEvent();
    void beginUpdate();
    void endUpdate();
    boolean inUpdate();
    // undo
    void addUndoableEditListener(UndoableEditListener listener);
    void removeUndoableEditListener(UndoableEditListener listener);
    void postEdit(UndoableEdit uae);
    void lockUndo();
    void unlockUndo();
    // data
    void getText(int offset, int length, Segment txt) throws BadLocationException;
    Element getRootElement();
    Element getParagraphElement(int offs, Position.Bias bias) 
	throws BadLocationException;
    // modify
    void remove(int offs, int len) throws BadLocationException;
    void insertString(int offset, String str, String format) 
	throws BadLocationException;
    Hashtable getStyle(String name);
}
