/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: DocumentEvent.java,v 1.4 2001/08/20 09:23:39 max Exp $
 *
 */

package make.swing.text;

import java.io.PrintStream;
import java.util.Hashtable;
import java.util.Enumeration;
import java.util.EventObject;
import make.util.Debug;

public final class DocumentEvent extends EventObject {
    /***properties***************************/
    protected Hashtable changes = new Hashtable();
    protected int position=-1, inserted=0, removed=0;
    protected boolean isUndo = false;
    /***Constructor*************************/
    public DocumentEvent(Document _doc) {
	super(_doc);
	/*if (Debug.DEBUG && !_doc.inUndo())
	  throw new InternalError("treeChangeEvent created without undo");*/
    }
    public DocumentEvent(Document _doc, boolean _iu) {
	super(_doc);
	isUndo = _iu;
	/*if (Debug.DEBUG && !isUndo && !_doc.inUndo())
	  throw new InternalError("treeChangeEvent created without undo");*/
    }
    /***Change********************************/
    public void createParentChange(Element el) {
	Element p;
	while ((p=el.getParent())!=null) {
	    final int index = p.indexOf(el);
	    ContainerChange chg = getContainerChange(p);
	    if (chg==null) {
		chg = isUndo
		    ?new ExtendedContainerChange(p)
		    :new ContainerChange(p);
		changes.put(p, chg);
	    } else if (chg.isTouched(index))
		break;
	    chg.childChanged(index);
	    el = p;
	}
    }
    public ContainerChange createContainerChange(Element el) {
	ContainerChange ec = getContainerChange(el);
	if (ec==null)
	    putChange(el, ec = isUndo
		      ?new ExtendedContainerChange(el)
		      :new ContainerChange(el));
	return ec;
    }
    public void putChange(Element el, Object chg) {
	createParentChange(el);
	changes.put(el, chg);
    }
    public void removed(Element el, int p, int count) {
	createParentChange(el);
	if (position==-1 || p<position) position = p;
	removed += count;
	//System.err.println("removed: p="+p+" count="+count);
    }
    public void inserted(Element el, int p, int count) {
	if (count>0) {
	    createParentChange(el);
	    if (position==-1 || p<=position) position = p;
	    inserted += count;
	}
	//System.err.println("inserted: p="+p+" count="+count);
    }
    /***Info**********************************/
    public Document getDocument() { return (Document)getSource(); }
    public Object getChange(Element el) {
	return changes.get(el);
    }
    public ContainerChange getContainerChange(Element el) {
	return (ContainerChange)getChange(el);
    }
    public int getPosition() { return position; }
    public int getInsertedCount() { return inserted; }
    public int getRemovedCount() { return removed; }
    public boolean isValid() {
	return (position!=-1 && (inserted>0 || removed>0)) || !changes.isEmpty();
    }
    public void dump(PrintStream out) {
	if (Debug.DEBUG) {
	    out.println("DocumentEvent: pos="+position+" ins="+inserted+" rem="+removed+" {");
	    for (Enumeration enum=changes.keys(); enum.hasMoreElements();) {
		Object key = enum.nextElement();
		Object val = changes.get(key);
		out.println("  "+key+" => "+val);
	    }
	    out.println("}");
	}
    }
}
