/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: ElementUndoableEdit.java,v 1.3 2001/08/20 09:23:39 max Exp $
 *
 */

package make.swing.text;

import javax.swing.undo.AbstractUndoableEdit;
import make.util.Debug;

public abstract class ElementUndoableEdit extends AbstractUndoableEdit {
    /***CONST********************************/
    public static final boolean DUMP = false;
    /***properties**************************/
    protected Element element;
    private int debugStart = -1;
    private boolean connected;
    /***Constructor*************************/
    public ElementUndoableEdit(Element _el) {
	element = _el;
	if (Debug.DEBUG)
	    debugStart = element.getStartOffset();
	Element el = element;
	while (el.getParent()!=null)
	    el = el.getParent();
	connected = el==element.getDocument().getRootElement();
	if (DUMP)
	    System.err.println(element+": connected="+connected);
    }
    protected DocumentEvent getEvent() { 
	return element.getDocument().getUndoEvent();
    }
    protected ContainerChange createContainerChange() {
	return getEvent().createContainerChange(element);
    }
    /***Public***********************************/
    public final boolean isConnected() { return connected; }
    public void inserted(int pos, int len) {
	if (connected)
	    getEvent().inserted(element, pos, len);
    }
    public void removed(int pos, int len) {
	if (connected)
	    getEvent().removed(element, pos, len);
    }
    /***AbstractUndoableEdit********************/
    public void undo() {
	super.undo();
	if (Debug.DEBUG)
	    if (debugStart!=element.getStartOffset()) {
		System.err.println("FATAL ERROR in undo from "+this);
		System.err.println("  el = "+element);
		System.err.println("  debugStart = "+debugStart+
				   " start="+element.getStartOffset());
		throw new InternalError();
	    }
    }
    public void redo() {
	super.redo();
	if (Debug.DEBUG)
	    if (debugStart!=element.getStartOffset()) {
		System.err.println("FATAL ERROR in redo from "+this);
		System.err.println("  el = "+element);
		System.err.println("  debugStart = "+debugStart+
				   " start="+element.getStartOffset());
		throw new InternalError();
	    }
    }
}
