/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: EmptyView.java,v 1.4 2001/08/20 09:23:39 max Exp $
 *
 */

package make.swing.text.view;

import java.awt.Shape;
import java.awt.FontMetrics;
import java.awt.Graphics;
import make.swing.text.Element;
import make.swing.text.DocumentEvent;

public final class EmptyView extends View {
    /***properties****************************/
    protected FontMetrics metrics;
    protected int start, end;
    /***Constructor******************************/
    public EmptyView(Element el) { 
	super(el); 
	start = el.getStartOffset(); 
	end = el.getEndOffset();
    }
    public EmptyView(Element el, int _position) { 
	super(el); start = end = _position;
    }
    public EmptyView(int _s, int _e) {
	super(null);
	start = _s; end = _e;
    }
    /***View******************************************/
    public int getNextVisualPositionFrom(int pos, int direction) {
	if (DUMP_NEXTVISUAL)
	    System.err.println(this+": nextVisual pos="+pos+" ret="+(pos==-1?start:-1));
	return pos==-1?start:-1;
    }
    public float getPreferredSpan(int axis) { 
	return 0.0f;
    }
    public float getMaximumSpan(int axis) {
	return Integer.MAX_VALUE;
    }
    public Shape modelToView(int pos, Shape a) {
	return a;
    }
    public void paint(Graphics g, Shape allocation) {}
    public int viewToModel(float x, float y, Shape a) {
	return start;
    }
    public int getStartOffset() { return start; }
    public int getEndOffset() { return end; }
    public void documentChanged(DocumentEvent evt, Shape a, ViewFactory vf) {}
}
