/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: NullView.java,v 1.2 2001/08/20 09:23:39 max Exp $
 *
 */

package make.swing.text.view;

import java.awt.Shape;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.Font;
import java.awt.font.FontRenderContext;
import javax.swing.text.BadLocationException;
import make.swing.text.TextComponent;
import make.swing.text.Element;
import make.swing.text.Document;
import make.swing.text.DocumentEvent;
import make.swing.text.TextUI;
import make.swing.text.view.View;
import make.swing.text.view.ViewFactory;

public final class NullView extends View {
    /*Constructor******************************/
    public NullView(Element el) { super(el); }
    /*View******************************************/
    public float getPreferredSpan(int axis) { 
	if (axis==Y_AXIS) {
	    // find font
	    TextComponent target = getContainer();
	    TextUI ui = target.getUI();
	    Element attr = getElement();
	    Document doc = getDocument();
	    Font font = ui.getFont(target, attr);
	    if (font==null)
		return 1;
	    //
	    Graphics2D g2d = (Graphics2D)getContainer().getGraphics();
	    try {
		FontRenderContext fontRenderContext
		    = g2d.getFontRenderContext();
		return (int)font.getMaxCharBounds
		    (fontRenderContext).getHeight();
	    } finally {
		if (g2d!=null)
		    g2d.dispose();
	    }
	} else {
	    return 0;
	}
    }
    public Shape modelToView(int pos, Shape a) {
	return a;
    }
    public void paint(Graphics g, Shape allocation) {}
    public int viewToModel(float x, float y, Shape a) {
	return getElement().getStartOffset();
    }
    public int getNextVisualPositionFrom(int pos, int direction) 
	throws BadLocationException {
	switch (direction) {
	case NORTH: case SOUTH:
	    return pos==-1 ? getStartOffset() : -1;
	case WEST:
	    return pos==-1 || pos>getStartOffset() ? getStartOffset() : -1;
	case EAST:
	    return pos==-1 ? getStartOffset() : -1;
	default:
	    throw new IllegalArgumentException("Bad direction: " + direction);
	}
    }
    public void documentChanged(DocumentEvent evt, Shape a, ViewFactory vf) {}
}
