/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: StyleView.java,v 1.4 2001/08/20 09:23:39 max Exp $
 *
 */

package make.swing.text.view;

import javax.swing.text.Position;
import java.util.Vector;
import make.swing.text.Element;

public class StyleView extends BoxView implements BreakableView {
    /***properties***************************/
    protected Element element;
    /***Constructor*****************************/
    public StyleView(Element el) {
	super(el, X_AXIS);
	element = el;
	setInsets((short)0,(short)0,(short)0,(short)0);
	minorCursorWrap = false;
    }
    /***BreakableBoxView***********************/
    public View getPoolParent() { return this; }
    public int getPoolViewIndexAt(int position, Position.Bias bias) {
	return getElement().getIndexAt(position, bias);
    }
    public View getPoolView(int index) { return getView(index); }
    public int getPoolViewCount() { return getViewCount(); }
    public View createView(Vector children) {
	return new BrokenStyleView(this, children);
    }
    /***View**********************************/
    public View createFragment(int p0, int p1) {
	return BreakUtil.createFragment(this, p0, p1);
    }
    public int getBreakWeight(int axis, int offset, float x, float len) {
	return axis==X_AXIS && getViewCount()>0
	    ?BreakUtil.getBreakWeight(this, axis, offset, x, len).weight
	    :super.getBreakWeight(axis, offset, x, len);
    }
    public View breakView(int axis, int offset, float x, float len) {
	if (axis==X_AXIS) {
	    return BreakUtil.breakView(this, axis, offset, x, len);
	} else
	    return super.breakView(axis, offset, x, len);
    }
}

class BrokenStyleView extends BrokenBoxView {
    /***properties*********************************/
    protected Vector views;
    /***Constructor*****************************/
    public BrokenStyleView(StyleView _p, Vector _v) {
	super(_p, _p.getAxis());
	views = _v;
    }
    protected void loadChildren(ViewFactory f) {
	final int n = views.size();
	View[] v = new View[n];
	for (int z=0; z<n; z++)
	    v[z] = (View)views.elementAt(z);
	replace(0, 0, v);
    }
}
