/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: CounterTable.java,v 1.3 2001/08/20 09:23:39 max Exp $
 *
 */

package make.util;

public class CounterTable {
    /***properties****************************/
    protected Object[] keys;
    protected int[] counts;
    protected int size = 0, resizeDelta;
    /***Constructor****************************/
    public CounterTable(int _sz, int _rd) {
	keys = new Object[_sz];
	counts = new int[_sz];
	resizeDelta = _rd;
    }
    public CounterTable(int _rd) {
	this(_rd*2, _rd);
    }
    public CounterTable() {
	this(16);
    }
    /***Add******************************/
    public int add(Object key, int d) {
	for (int z=0; z<size; z++)
	    if (key.equals(keys[z])) {
		counts[z] += d; return counts[z];
	    }
	if (size==keys.length) {
	    Object[] kn = new Object[size+resizeDelta];
	    System.arraycopy(keys, 0, kn, 0, size);
	    keys = kn;
	    int[] cn = new int[size+resizeDelta];
	    System.arraycopy(counts, 0, cn, 0, size);
	    counts = cn;
	}
	keys[size] = key;
	counts[size] = d;
	size++;
	return d;
    }
    public int inc(Object key) {
	return add(key, 1);
    }
    /***Info*******************************/
    public final Object getKey(int idx) { return keys[idx]; }
    public final int getCount(int idx) { return counts[idx]; }
    public final int getCount(Object key) {
	for (int z=0; z<size; z++)
	    if (key.equals(keys[z]))
		return counts[z];
	return 0;
    }
    public final int size() { return size; }
}
