/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: PhonetCounter.java,v 1.4 2001/08/20 09:23:39 max Exp $
 *
 */

package make.util;

import java.util.Hashtable;
import java.util.Enumeration;

/**
 * This class converts a specified text into its Phonet equivalent
 * and counts all phonet codes contained within. This is useful
 * for full-text search algorithms.
 */
public class PhonetCounter {
    /*properties*******************************/
    protected Phonet phonet;
    protected Hashtable counts = new Hashtable();
    /*Constructor*******************************/
    public PhonetCounter(Phonet _phonet) {
	phonet = _phonet;
    }
    protected void add(String s, int count) {
	Integer i = (Integer)counts.get(s);
	int oldCount = i==null ? 0 : i.intValue();
	counts.put(s, new Integer(oldCount+count));
    }
    public void clear() {
	counts.clear();
    }
    protected void addWord(String w) {
	String ph = phonet.translate(w);
	if (ph!=null && ph.length()>1)
	    add(ph, 1);
    }
    public void add(String s) {
	StringBuffer word = new StringBuffer();
	final char[] sa = s.toCharArray();
	for (int z=0; z<sa.length; z++) {
	    final char ch = sa[z];
	    if (Character.isLetter(ch)) {
		word.append(ch);
	    } else if (Character.isDigit(ch)) {
		// no words with digits
		word.setLength(0);
		for (z++; z<sa.length; z++)
		    if (!Character.isLetter(sa[z]))
			break;
	    } else {
		if (word.length()>0) {
		    addWord(word.toString());
		    word.setLength(0);
		}
	    }
	}
	if (word.length()>0)
	    addWord(word.toString());
    }
    public Enumeration getWords() {
	return counts.keys();
    }
    public int getCount(String word) {
	Integer i = (Integer)counts.get(word);
	return i==null
	    ?0
	    :i.intValue();
    }
}
