/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: Strings.java,v 1.11 2001/12/19 17:31:16 max Exp $
 *
 */

package make.util;

import java.util.StringTokenizer;
import java.util.Vector;
import java.util.Date;
import java.util.Locale;
import java.text.ParseException;
import java.text.DateFormat;
import java.text.NumberFormat;
import java.text.SimpleDateFormat;

/**
 * This class contains many helper functions to work 
 * with String objects
 */
public abstract class Strings {
    /*CONST********************************/
    public static final int DATETIME = 0;
    public static final int DATE = 1;
    public static final int TIME = 2;
    /*static********************************/
    public static final DateFormat[] storeDateFormats = {
        new SimpleDateFormat("yyyy/MM/dd HH:mm"),
        new SimpleDateFormat("yyyy/MM/dd"),
        new SimpleDateFormat("HH:mm"),
    };
    public static DateFormat[] displayDateFormats = {
        DateFormat.getDateTimeInstance(DateFormat.SHORT, DateFormat.SHORT),
        DateFormat.getDateInstance(DateFormat.SHORT),
        DateFormat.getTimeInstance(DateFormat.SHORT),
    };
    public static NumberFormat storeIntegerFormat
        = NumberFormat.getNumberInstance(Locale.US);
    public static NumberFormat displayIntegerFormat
        = NumberFormat.getNumberInstance();
    static {
        storeIntegerFormat.setParseIntegerOnly(true);
        storeIntegerFormat.setGroupingUsed(false);
        displayIntegerFormat.setParseIntegerOnly(true);
    }
    /*Static*******************************/
    public static String trim(String s) {
        if (s==null) return null;
        s = s.trim();
        return s.length()==0?null:s;
    }
    public static String normalize(String s, boolean preserveLeft, 
                                   boolean preserveRight) {
        if (s==null)
            throw new NullPointerException("s==null");
        if ("".equals(s)) 
            return "";
        StringBuffer sb = new StringBuffer();
        char[] data = s.toCharArray();
        int z = 0;
        if (!preserveLeft)
            while (z<data.length && Character.isWhitespace(data[z])) z++;
        boolean wasSpace = false;
        for (; z<data.length; z++) {
            if (Character.isWhitespace(data[z]))
                wasSpace = true;
            else {
                if (wasSpace) {
                    sb.append(' ');
                    wasSpace = false;
                }
                sb.append(data[z]);
            }
        }
        if (wasSpace && preserveRight)
            sb.append(' ');
        return sb.toString();
    }
    public static String normalize(String s) {
        return normalize(s, false, false);
    }
    public static boolean equals(String a, String b) {
        return a==null
            ?b==null
            :a.equals(b);
    }
    public static String[] tokenize(String input) {
        Vector v = new Vector();
        StringTokenizer t = new StringTokenizer(input);
        while (t.hasMoreTokens())
            v.addElement(t.nextToken());
        String[] cmd = new String[v.size()];
        for (int i = 0; i < cmd.length; i++)
            cmd[i] = (String) v.elementAt(i);
        return cmd;
    }
    public static int lookup(Object[] list, Object s) {
        for (int z=0; z<list.length; z++)
            if (s.equals(list[z]))
                return z;
        return -1;
    }
    public static int lookup(String[] list, String s) {
        s = trim(s);
        if (s==null) return -1;
        for (int z=0; z<list.length; z++)
            if (s.equals(list[z]))
                return z;
        return -1;
    }
    public static int lookup(byte[] list, byte s) {
        for (int z=0; z<list.length; z++)
            if (s==list[z])
                return z;
        return -1;
    }
    public static Object translate(Object[] list1, Object[] list2, Object o) {
        if (Debug.DEBUG && list1.length!=list2.length)
            throw new IllegalArgumentException();
        final int idx = lookup(list1, o);
        return idx==-1 ? null : list2[idx];
    }
    public static String translate(String[] list1, String[] list2, String s) {
        if (Debug.DEBUG && list1.length!=list2.length)
            throw new IllegalArgumentException();
        final int idx = lookup(list1, s);
        return idx==-1 ? null : list2[idx];
    }
    public static byte translate(String[] list1, byte[] list2, String s, byte def) {
        final int idx = lookup(list1, s);
        return idx==-1 ? def : list2[idx];
    }
    public static String translate(byte[] list1, String[] list2, byte s, String def) {
        final int idx = lookup(list1, s);
        return idx==-1 ? def : list2[idx];
    }
    public static String translate(String s, char a, char b) {
        StringBuffer sb = new StringBuffer(s.length());
        for (int z=0; z<s.length(); z++) {
            char ch = s.charAt(z);
            if (ch==a)
                ch = b;
            sb.append(ch);
        }
        return sb.toString();
    }

    /*URL**************************************/
    public static String escapeURLParameter(String s) {
        final int len = s.length();
        StringBuffer sb = new StringBuffer(len+8);
        for (int z=0; z<len; z++) {
            final char ch = s.charAt(z);
            if ((ch>='a' && ch<='z') ||
                (ch>='A' && ch<='Z') ||
                (ch>='0' && ch<='9')) {
                sb.append(ch);
            } else if (ch==' ') {
                sb.append('+');
            } else if ((((int)ch)&~0xff)!=0) {
                // this is a code that does not fit into one escaped byte
                // => just add whitespace...
                sb.append('+');
            } else {
                sb.append('%');
                // here we just cast the character into a byte
                // maybe we should let some Java class handle the correct encoding
                // but... Apache Tomcat does the same as here ;)
                int b = (int)ch;
                int digit;
                digit = (b>>4) & 0xf;
                if (digit>=10)
                    sb.append((char)('A'+digit-10));
                else
                    sb.append((char)('0'+digit));
                digit = b & 0xf;
                if (digit>=10)
                    sb.append((char)('A'+digit-10));
                else
                    sb.append((char)('0'+digit));
            }
        }
        return sb.toString();
    }
    public static String unescapeURLParameter(String s) {
        final int len = s.length();
        StringBuffer sb = new StringBuffer(len);
        for (int z=0; z<len; z++) {
            final char ch = s.charAt(z);
            if (ch=='+') {
                sb.append(' ');
            } else if (ch=='%' && z<(len-2)) {
                // decode a hex number
                int digit1 = Character.digit(s.charAt(++z), 16);
                int digit2 = Character.digit(s.charAt(++z), 16);
                if (digit1<0 || digit2<0) {
                    // invalid hex digit, add a whitespace instead
                    sb.append(' ');
                } else {
                    // convert to a char and add to the string
                    sb.append((char)(digit1*16+digit2));
                }
            } else {
                // FIXME: there may be more escape sequences (unicode?),
                // implement these
                sb.append(ch);
            }
        }
        return sb.toString();
    }

    /*XML***************************************/
    public static String escapeXMLText(String s, boolean preserveWhitespaces) {
        if (s==null)
            return "";
        final int len = s.length();
        StringBuffer str = new StringBuffer((len*5)/4);
        for (int i=0; i<len; i++) {
            final char ch = s.charAt(i);
            if (!preserveWhitespaces && Character.isWhitespace(ch))
                str.append(' ');
            else switch ( ch ) {
            case '<':
                str.append("&lt;");
                break;
            case '>':
                str.append("&gt;");
                break;
            case '&':
                str.append("&amp;");
                break;
            case '"':
                str.append("&quot;");
                break;
            default:
                str.append(ch);
            }
        }
        return str.toString();
    }
    public static String escapeXMLText(String s) {
        return escapeXMLText(s, false);
    }
    public static String escapeWDDXText(String s, boolean preserveWhitespaces) {
        if (s==null)
            return "";
        final int len = s.length();
        StringBuffer str = new StringBuffer((len*3)/2);
        for (int i=0; i<len; i++) {
            final char ch = s.charAt(i);
            if (!preserveWhitespaces && Character.isWhitespace(ch))
                str.append(' ');
            else if (Character.isDigit(ch) || (ch>='a' && ch<='z') ||
                     (ch>='A' && ch<='Z') || ch=='/' || ch==':' || ch=='-'
                     || ch=='.' || ch==',' || ch=='_' || ch==';' || ch=='+'
                     || ch=='=' || ch=='-' || ch=='\\' || ch=='(' || ch==')')
                str.append(ch);
            else {
                str.append("&amp;#");
                str.append((int)ch);
                str.append(';');
            }
        }
        return str.toString();
    }
    public static String escapeWDDXText(String s) {
        return escapeWDDXText(s, false);
    }

    /*Time********************************/
    public static final long MILLI = 1;
    public static final long SECOND = MILLI*1000;
    public static final long MINUTE = SECOND*60;
    public static final long HOUR = MINUTE*60;
    public static final long DAY = HOUR*24;
    public static final long WEEK = DAY*7;
    public static final long YEAR = (DAY*36525)/100;
    public static final long MONTH = YEAR/12;
    public static long parseTimeSpan(String ar) 
        throws ParseException {
        char[] arc = ar.toCharArray();
        int pos = 0;
        long span = 0;
        long factor = 1;
        while (pos<arc.length) {
            if (arc[pos]=='+') {
                factor = 1; pos++;
            } else if (arc[pos]=='-') {
                factor = -1; pos++;
            } else {
                int letter = pos;
                while (letter<arc.length)
                    if (Character.isDigit(arc[letter]))
                        letter++;
                    else if (Character.isLetter(arc[letter])) {
                        if (letter==pos)
                            throw new ParseException("", letter);
                        int nr;
                        try {
                            nr = Integer.parseInt(ar.substring(pos, letter));
                        } catch (NumberFormatException e) {
                            throw new ParseException(e.getLocalizedMessage(), pos);
                        }
                        switch (arc[letter]) {
                        case 'y': span += factor*nr*YEAR; break;
                        case 'M': span += factor*nr*MONTH; break;
                        case 'd': span += factor*nr*DAY; break;
                        case 'h': span += factor*nr*HOUR; break;
                        case 'm': span += factor*nr*MINUTE; break;
                        case 's': span += factor*nr*SECOND; break;
                        default: throw new ParseException("Unknown unit: "+arc[letter], letter);
                        }
                        break;
                    } else
                        throw new ParseException("", letter);
                if (letter>=arc.length)
                    throw new ParseException("", letter);
                pos = letter+1;
            }
        }
        return span;
    }
    public static Date parseDateInput(String d) throws ParseException {
        d = trim(d);
        if (d==null)
            return null;
        ParseException exception = null;
        for (int z=0; z<displayDateFormats.length; z++)
            try {
                return displayDateFormats[z].parse(d);
            } catch (ParseException e) {
                exception = e;
            }
        throw exception;
    }
    public static String format(boolean b) {
        return b?"yes":"no";
    }
    public static boolean parseBoolean(String s) 
        throws ParseException {
        if (s==null) throw new NullPointerException();
        if (s.equals("yes") || s.equals("true"))
            return true;
        else if (s.equals("no") || s.equals("false"))
            return false;
        else
            throw new ParseException(s, 0);
    }
}
