/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: WDDXUtil.java,v 1.6 2001/08/20 09:23:39 max Exp $
 *
 */

package make.xml;

import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.Document;
import java.util.Vector;
import java.util.Hashtable;
import java.util.Enumeration;
import java.util.Date;
import java.io.IOException;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.io.Writer;
import make.util.Strings;

public abstract class WDDXUtil {
    /***Static********************************/
    public static void addStructValue(Element stru, String name, Node val) {
	Element var = stru.getOwnerDocument().createElement("var");
	var.setAttribute("name", name);
	var.appendChild(val);
	stru.appendChild(var);
    }
    public static void addStructString(Element stru, String name, String val) {
	Document doc = stru.getOwnerDocument();
	Element str = doc.createElement("string");
	str.appendChild(doc.createTextNode(val));
	addStructValue(stru, name, str);
    }
    public static void addStructInteger(Element stru, String name, int val) {
	Document doc = stru.getOwnerDocument();
	Element str = doc.createElement("number");
	str.appendChild(doc.createTextNode(""+val));
	addStructValue(stru, name, str);
    }
    public static void addStructLong(Element stru, String name, long val) {
	Document doc = stru.getOwnerDocument();
	Element str = doc.createElement("number");
	str.appendChild(doc.createTextNode(""+val));
	addStructValue(stru, name, str);
    }
    public static Element createPacket() {
	Document doc = DOMUtil.createDocument();
	Element packet = doc.createElement("wddxPacket");
	packet.setAttribute("version", "0.9");
	doc.appendChild(packet);
	return packet;
    }
    public static void print(Writer wr, Object o) throws IOException {
	if (o instanceof Vector) {
	    Vector vc = (Vector)o;
	    wr.write("<array length=\""+vc.size()+"\">");
	    for (Enumeration enum=vc.elements(); enum.hasMoreElements();)
		print(wr, enum.nextElement());
	    wr.write("</array>\n");
	} else if (o instanceof Hashtable) {
	    Hashtable ht = (Hashtable)o;
	    wr.write("<struct>");
	    for (Enumeration enum=ht.keys(); enum.hasMoreElements();) {
		String name = (String)enum.nextElement();
		wr.write("<var name=\""+Strings.escapeWDDXText(name)+"\">");
		print(wr, ht.get(name));
		wr.write("</var>");
	    }
	    wr.write("</struct>\n");
	} else if (o instanceof String) {
	    wr.write("<string>");
	    wr.write(Strings.escapeWDDXText((String)o));
	    wr.write("</string>");
	} else if (o instanceof Number) {
	    wr.write("<number>");
	    wr.write(o.toString());
	    wr.write("</number>");
	} else if (o instanceof Boolean) {
	    /*wr.write("<boolean>");
	      wr.write(o.toString());
	      wr.write("</boolean>");*/
	    print(wr, ""+o);
	} else if (o instanceof Date) {
	    wr.write("<string>");
	    //wr.write("<dateTime>");
	    wr.write(o.toString());
	    //wr.write("</dateTime>");
	    wr.write("</string>");
	} else
	    throw new InternalError("unrecognized WDDX type: "+o.getClass());
    }
    public static void printPacket(Writer wr, String encoding, 
				   Object o) throws IOException {
	wr.write("<?xml version=\"1.0\" encoding=\""+encoding+"\"?>\n"+
		 "<wddxPacket version=\"0.9\"><data>\n");
	print(wr, o);
	wr.write("</data><wddxPacket>");
    }
    public static void printPacket(OutputStream os, String encoding, 
				   Object o) throws IOException {
	Writer wr = new OutputStreamWriter(os, encoding);
	printPacket(wr, encoding, o);
	wr.close();
    }
}
