/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: AttributeSlot.java,v 1.4 2001/08/20 09:23:39 max Exp $
 *
 */

package make.xml.slot;

import java.text.ParseException;
import org.w3c.dom.Attr;
import org.w3c.dom.Element;
import make.datamodel.slot.Slot;
import make.xml.AttributeType;

public class AttributeSlot implements Slot {
    /***properties*****************************/
    protected Element element;
    protected String attributeName;
    protected Attr attribute;
    protected AttributeType type;
    /***Constructor*****************************/
    public AttributeSlot(Element _el, String _an, AttributeType _type) {
	element = _el; attributeName = _an; type = _type;
	attribute = element.getAttributeNode(attributeName);
    }
    public AttributeSlot(Attr _attr, AttributeType _type) {
	attribute = _attr; type = _type;
	element = (Element)attribute.getParentNode();
	attributeName = attribute.getName();
    }
    public AttributeSlot(Attr _attr) {
	this(_attr, null);
    }
    /***Slot**********************************/
    public void setValue(Object v) throws ParseException {
	if (v==null) {
	    if (attribute!=null) {
		if (type!=null && type.isRequired())
		    throw new ParseException("Bitte geben Sie hier einen Wert ein.", 0);
		element.removeAttributeNode(attribute);
		/*if (element.getChildNodes().getLength()==0 &&
		  element.getAttributes().getLength()==0)
		  remove element from its parent? */
	    }
	} else {
	    if (attribute==null) {
		attribute = element.getOwnerDocument().createAttribute(attributeName);
		element.setAttributeNode(attribute);
	    }
	    attribute.setValue(v.toString());
	}
    }
    public Object getValue() throws ParseException {
	return attribute.getValue();
    }
}
